"""
RemixIcon icons data and utilities.
"""

# RemixIcon v4.7.0 icon list
REMIX_ICONS = {
    "Arrows": {
        "arrow-down-box-fill": "arrow down box fill",
        "arrow-down-box-line": "arrow down box line",
        "arrow-down-circle-fill": "arrow down circle fill",
        "arrow-down-circle-line": "arrow down circle line",
        "arrow-down-double-fill": "arrow down double fill",
        "arrow-down-double-line": "arrow down double line",
        "arrow-down-fill": "arrow down fill",
        "arrow-down-line": "arrow down line",
        "arrow-down-long-fill": "arrow down long fill",
        "arrow-down-long-line": "arrow down long line",
        "arrow-down-s-fill": "arrow down s fill",
        "arrow-down-s-line": "arrow down s line",
        "arrow-down-wide-fill": "arrow down wide fill",
        "arrow-down-wide-line": "arrow down wide line",
        "arrow-drop-down-fill": "arrow drop down fill",
        "arrow-drop-down-line": "arrow drop down line",
        "arrow-drop-left-fill": "arrow drop left fill",
        "arrow-drop-left-line": "arrow drop left line",
        "arrow-drop-right-fill": "arrow drop right fill",
        "arrow-drop-right-line": "arrow drop right line",
        "arrow-drop-up-fill": "arrow drop up fill",
        "arrow-drop-up-line": "arrow drop up line",
        "arrow-go-back-fill": "arrow go back fill",
        "arrow-go-back-line": "arrow go back line",
        "arrow-go-forward-fill": "arrow go forward fill",
        "arrow-go-forward-line": "arrow go forward line",
        "arrow-left-box-fill": "arrow left box fill",
        "arrow-left-box-line": "arrow left box line",
        "arrow-left-circle-fill": "arrow left circle fill",
        "arrow-left-circle-line": "arrow left circle line",
        "arrow-left-double-fill": "arrow left double fill",
        "arrow-left-double-line": "arrow left double line",
        "arrow-left-down-box-fill": "arrow left down box fill",
        "arrow-left-down-box-line": "arrow left down box line",
        "arrow-left-down-fill": "arrow left down fill",
        "arrow-left-down-line": "arrow left down line",
        "arrow-left-down-long-fill": "arrow left down long fill",
        "arrow-left-down-long-line": "arrow left down long line",
        "arrow-left-fill": "arrow left fill",
        "arrow-left-line": "arrow left line",
        "arrow-left-long-fill": "arrow left long fill",
        "arrow-left-long-line": "arrow left long line",
        "arrow-left-right-fill": "arrow left right fill",
        "arrow-left-right-line": "arrow left right line",
        "arrow-left-s-fill": "arrow left s fill",
        "arrow-left-s-line": "arrow left s line",
        "arrow-left-up-box-fill": "arrow left up box fill",
        "arrow-left-up-box-line": "arrow left up box line",
        "arrow-left-up-fill": "arrow left up fill",
        "arrow-left-up-line": "arrow left up line",
        "arrow-left-up-long-fill": "arrow left up long fill",
        "arrow-left-up-long-line": "arrow left up long line",
        "arrow-left-wide-fill": "arrow left wide fill",
        "arrow-left-wide-line": "arrow left wide line",
        "arrow-right-box-fill": "arrow right box fill",
        "arrow-right-box-line": "arrow right box line",
        "arrow-right-circle-fill": "arrow right circle fill",
        "arrow-right-circle-line": "arrow right circle line",
        "arrow-right-double-fill": "arrow right double fill",
        "arrow-right-double-line": "arrow right double line",
        "arrow-right-down-box-fill": "arrow right down box fill",
        "arrow-right-down-box-line": "arrow right down box line",
        "arrow-right-down-fill": "arrow right down fill",
        "arrow-right-down-line": "arrow right down line",
        "arrow-right-down-long-fill": "arrow right down long fill",
        "arrow-right-down-long-line": "arrow right down long line",
        "arrow-right-fill": "arrow right fill",
        "arrow-right-line": "arrow right line",
        "arrow-right-long-fill": "arrow right long fill",
        "arrow-right-long-line": "arrow right long line",
        "arrow-right-s-fill": "arrow right s fill",
        "arrow-right-s-line": "arrow right s line",
        "arrow-right-up-box-fill": "arrow right up box fill",
        "arrow-right-up-box-line": "arrow right up box line",
        "arrow-right-up-fill": "arrow right up fill",
        "arrow-right-up-line": "arrow right up line",
        "arrow-right-up-long-fill": "arrow right up long fill",
        "arrow-right-up-long-line": "arrow right up long line",
        "arrow-right-wide-fill": "arrow right wide fill",
        "arrow-right-wide-line": "arrow right wide line",
        "arrow-turn-back-fill": "arrow turn back fill",
        "arrow-turn-back-line": "arrow turn back line",
        "arrow-turn-forward-fill": "arrow turn forward fill",
        "arrow-turn-forward-line": "arrow turn forward line",
        "arrow-up-box-fill": "arrow up box fill",
        "arrow-up-box-line": "arrow up box line",
        "arrow-up-circle-fill": "arrow up circle fill",
        "arrow-up-circle-line": "arrow up circle line",
        "arrow-up-double-fill": "arrow up double fill",
        "arrow-up-double-line": "arrow up double line",
        "arrow-up-down-fill": "arrow up down fill",
        "arrow-up-down-line": "arrow up down line",
        "arrow-up-fill": "arrow up fill",
        "arrow-up-line": "arrow up line",
        "arrow-up-long-fill": "arrow up long fill",
        "arrow-up-long-line": "arrow up long line",
        "arrow-up-s-fill": "arrow up s fill",
        "arrow-up-s-line": "arrow up s line",
        "arrow-up-wide-fill": "arrow up wide fill",
        "arrow-up-wide-line": "arrow up wide line",
        "collapse-diagonal-2-fill": "collapse diagonal 2 fill",
        "collapse-diagonal-2-line": "collapse diagonal 2 line",
        "collapse-diagonal-fill": "collapse diagonal fill",
        "collapse-diagonal-line": "collapse diagonal line",
        "collapse-horizontal-fill": "collapse horizontal fill",
        "collapse-horizontal-line": "collapse horizontal line",
        "collapse-vertical-fill": "collapse vertical fill",
        "collapse-vertical-line": "collapse vertical line",
        "contract-left-fill": "contract left fill",
        "contract-left-line": "contract left line",
        "contract-left-right-fill": "contract left right fill",
        "contract-left-right-line": "contract left right line",
        "contract-right-fill": "contract right fill",
        "contract-right-line": "contract right line",
        "contract-up-down-fill": "contract up down fill",
        "contract-up-down-line": "contract up down line",
        "corner-down-left-fill": "corner down left fill",
        "corner-down-left-line": "corner down left line",
        "corner-down-right-fill": "corner down right fill",
        "corner-down-right-line": "corner down right line",
        "corner-left-down-fill": "corner left down fill",
        "corner-left-down-line": "corner left down line",
        "corner-left-up-fill": "corner left up fill",
        "corner-left-up-line": "corner left up line",
        "corner-right-down-fill": "corner right down fill",
        "corner-right-down-line": "corner right down line",
        "corner-right-up-fill": "corner right up fill",
        "corner-right-up-line": "corner right up line",
        "corner-up-left-double-fill": "corner up left double fill",
        "corner-up-left-double-line": "corner up left double line",
        "corner-up-left-fill": "corner up left fill",
        "corner-up-left-line": "corner up left line",
        "corner-up-right-double-fill": "corner up right double fill",
        "corner-up-right-double-line": "corner up right double line",
        "corner-up-right-fill": "corner up right fill",
        "corner-up-right-line": "corner up right line",
        "drag-move-2-fill": "drag move 2 fill",
        "drag-move-2-line": "drag move 2 line",
        "drag-move-fill": "drag move fill",
        "drag-move-line": "drag move line",
        "expand-diagonal-2-fill": "expand diagonal 2 fill",
        "expand-diagonal-2-line": "expand diagonal 2 line",
        "expand-diagonal-fill": "expand diagonal fill",
        "expand-diagonal-line": "expand diagonal line",
        "expand-diagonal-s-2-fill": "expand diagonal s 2 fill",
        "expand-diagonal-s-2-line": "expand diagonal s 2 line",
        "expand-diagonal-s-fill": "expand diagonal s fill",
        "expand-diagonal-s-line": "expand diagonal s line",
        "expand-height-fill": "expand height fill",
        "expand-height-line": "expand height line",
        "expand-horizontal-fill": "expand horizontal fill",
        "expand-horizontal-line": "expand horizontal line",
        "expand-horizontal-s-fill": "expand horizontal s fill",
        "expand-horizontal-s-line": "expand horizontal s line",
        "expand-left-fill": "expand left fill",
        "expand-left-line": "expand left line",
        "expand-left-right-fill": "expand left right fill",
        "expand-left-right-line": "expand left right line",
        "expand-right-fill": "expand right fill",
        "expand-right-line": "expand right line",
        "expand-up-down-fill": "expand up down fill",
        "expand-up-down-line": "expand up down line",
        "expand-vertical-fill": "expand vertical fill",
        "expand-vertical-line": "expand vertical line",
        "expand-vertical-s-fill": "expand vertical s fill",
        "expand-vertical-s-line": "expand vertical s line",
        "expand-width-fill": "expand width fill",
        "expand-width-line": "expand width line",
        "scroll-to-bottom-fill": "scroll to bottom fill",
        "scroll-to-bottom-line": "scroll to bottom line",
        "skip-down-fill": "skip down fill",
        "skip-down-line": "skip down line",
        "skip-left-fill": "skip left fill",
        "skip-left-line": "skip left line",
        "skip-right-fill": "skip right fill",
        "skip-right-line": "skip right line",
        "skip-up-fill": "skip up fill",
        "skip-up-line": "skip up line",
    },
    "Buildings": {
        "ancient-gate-fill": "ancient gate fill",
        "ancient-gate-line": "ancient gate line",
        "ancient-pavilion-fill": "ancient pavilion fill",
        "ancient-pavilion-line": "ancient pavilion line",
        "bank-fill": "bank fill",
        "bank-line": "bank line",
        "building-2-fill": "building 2 fill",
        "building-2-line": "building 2 line",
        "building-3-fill": "building 3 fill",
        "building-3-line": "building 3 line",
        "building-4-fill": "building 4 fill",
        "building-4-line": "building 4 line",
        "building-fill": "building fill",
        "building-line": "building line",
        "community-fill": "community fill",
        "community-line": "community line",
        "government-fill": "government fill",
        "government-line": "government line",
        "home-2-fill": "home 2 fill",
        "home-2-line": "home 2 line",
        "home-3-fill": "home 3 fill",
        "home-3-line": "home 3 line",
        "home-4-fill": "home 4 fill",
        "home-4-line": "home 4 line",
        "home-5-fill": "home 5 fill",
        "home-5-line": "home 5 line",
        "home-6-fill": "home 6 fill",
        "home-6-line": "home 6 line",
        "home-7-fill": "home 7 fill",
        "home-7-line": "home 7 line",
        "home-8-fill": "home 8 fill",
        "home-8-line": "home 8 line",
        "home-9-fill": "home 9 fill",
        "home-9-line": "home 9 line",
        "home-fill": "home fill",
        "home-gear-fill": "home gear fill",
        "home-gear-line": "home gear line",
        "home-heart-fill": "home heart fill",
        "home-heart-line": "home heart line",
        "home-line": "home line",
        "home-office-fill": "home office fill",
        "home-office-line": "home office line",
        "home-smile-2-fill": "home smile 2 fill",
        "home-smile-2-line": "home smile 2 line",
        "home-smile-fill": "home smile fill",
        "home-smile-line": "home smile line",
        "home-wifi-fill": "home wifi fill",
        "home-wifi-line": "home wifi line",
        "hospital-fill": "hospital fill",
        "hospital-line": "hospital line",
        "hotel-fill": "hotel fill",
        "hotel-line": "hotel line",
        "school-fill": "school fill",
        "school-line": "school line",
        "store-2-fill": "store 2 fill",
        "store-2-line": "store 2 line",
        "store-3-fill": "store 3 fill",
        "store-3-line": "store 3 line",
        "store-fill": "store fill",
        "store-line": "store line",
        "tent-fill": "tent fill",
        "tent-line": "tent line",
    },
    "Business": {
        "advertisement-fill": "advertisement fill",
        "advertisement-line": "advertisement line",
        "archive-2-fill": "archive 2 fill",
        "archive-2-line": "archive 2 line",
        "archive-drawer-fill": "archive drawer fill",
        "archive-drawer-line": "archive drawer line",
        "archive-fill": "archive fill",
        "archive-line": "archive line",
        "archive-stack-fill": "archive stack fill",
        "archive-stack-line": "archive stack line",
        "at-fill": "at fill",
        "at-line": "at line",
        "attachment-fill": "attachment fill",
        "attachment-line": "attachment line",
        "award-fill": "award fill",
        "award-line": "award line",
        "bar-chart-2-fill": "bar chart 2 fill",
        "bar-chart-2-line": "bar chart 2 line",
        "bar-chart-box-ai-fill": "bar chart box ai fill",
        "bar-chart-box-ai-line": "bar chart box ai line",
        "bar-chart-box-fill": "bar chart box fill",
        "bar-chart-box-line": "bar chart box line",
        "bar-chart-fill": "bar chart fill",
        "bar-chart-grouped-fill": "bar chart grouped fill",
        "bar-chart-grouped-line": "bar chart grouped line",
        "bar-chart-horizontal-fill": "bar chart horizontal fill",
        "bar-chart-horizontal-line": "bar chart horizontal line",
        "bar-chart-line": "bar chart line",
        "bookmark-2-fill": "bookmark 2 fill",
        "bookmark-2-line": "bookmark 2 line",
        "bookmark-3-fill": "bookmark 3 fill",
        "bookmark-3-line": "bookmark 3 line",
        "bookmark-fill": "bookmark fill",
        "bookmark-line": "bookmark line",
        "briefcase-2-fill": "briefcase 2 fill",
        "briefcase-2-line": "briefcase 2 line",
        "briefcase-3-fill": "briefcase 3 fill",
        "briefcase-3-line": "briefcase 3 line",
        "briefcase-4-fill": "briefcase 4 fill",
        "briefcase-4-line": "briefcase 4 line",
        "briefcase-5-fill": "briefcase 5 fill",
        "briefcase-5-line": "briefcase 5 line",
        "briefcase-fill": "briefcase fill",
        "briefcase-line": "briefcase line",
        "bubble-chart-fill": "bubble chart fill",
        "bubble-chart-line": "bubble chart line",
        "calculator-fill": "calculator fill",
        "calculator-line": "calculator line",
        "calendar-2-fill": "calendar 2 fill",
        "calendar-2-line": "calendar 2 line",
        "calendar-check-fill": "calendar check fill",
        "calendar-check-line": "calendar check line",
        "calendar-close-fill": "calendar close fill",
        "calendar-close-line": "calendar close line",
        "calendar-event-fill": "calendar event fill",
        "calendar-event-line": "calendar event line",
        "calendar-fill": "calendar fill",
        "calendar-line": "calendar line",
        "calendar-schedule-fill": "calendar schedule fill",
        "calendar-schedule-line": "calendar schedule line",
        "calendar-todo-fill": "calendar todo fill",
        "calendar-todo-line": "calendar todo line",
        "cloud-fill": "cloud fill",
        "cloud-line": "cloud line",
        "cloud-off-fill": "cloud off fill",
        "cloud-off-line": "cloud off line",
        "copyleft-fill": "copyleft fill",
        "copyleft-line": "copyleft line",
        "copyright-fill": "copyright fill",
        "copyright-line": "copyright line",
        "creative-commons-by-fill": "creative commons by fill",
        "creative-commons-by-line": "creative commons by line",
        "creative-commons-fill": "creative commons fill",
        "creative-commons-line": "creative commons line",
        "creative-commons-nc-fill": "creative commons nc fill",
        "creative-commons-nc-line": "creative commons nc line",
        "creative-commons-nd-fill": "creative commons nd fill",
        "creative-commons-nd-line": "creative commons nd line",
        "creative-commons-sa-fill": "creative commons sa fill",
        "creative-commons-sa-line": "creative commons sa line",
        "creative-commons-zero-fill": "creative commons zero fill",
        "creative-commons-zero-line": "creative commons zero line",
        "customer-service-2-fill": "customer service 2 fill",
        "customer-service-2-line": "customer service 2 line",
        "customer-service-fill": "customer service fill",
        "customer-service-line": "customer service line",
        "donut-chart-fill": "donut chart fill",
        "donut-chart-line": "donut chart line",
        "flag-2-fill": "flag 2 fill",
        "flag-2-line": "flag 2 line",
        "flag-fill": "flag fill",
        "flag-line": "flag line",
        "flag-off-fill": "flag off fill",
        "flag-off-line": "flag off line",
        "global-fill": "global fill",
        "global-line": "global line",
        "honour-fill": "honour fill",
        "honour-line": "honour line",
        "id-card-fill": "id card fill",
        "id-card-line": "id card line",
        "inbox-2-fill": "inbox 2 fill",
        "inbox-2-line": "inbox 2 line",
        "inbox-archive-fill": "inbox archive fill",
        "inbox-archive-line": "inbox archive line",
        "inbox-fill": "inbox fill",
        "inbox-line": "inbox line",
        "inbox-unarchive-fill": "inbox unarchive fill",
        "inbox-unarchive-line": "inbox unarchive line",
        "info-card-fill": "info card fill",
        "info-card-line": "info card line",
        "line-chart-fill": "line chart fill",
        "line-chart-line": "line chart line",
        "links-fill": "links fill",
        "links-line": "links line",
        "mail-add-fill": "mail add fill",
        "mail-add-line": "mail add line",
        "mail-ai-fill": "mail ai fill",
        "mail-ai-line": "mail ai line",
        "mail-check-fill": "mail check fill",
        "mail-check-line": "mail check line",
        "mail-close-fill": "mail close fill",
        "mail-close-line": "mail close line",
        "mail-download-fill": "mail download fill",
        "mail-download-line": "mail download line",
        "mail-fill": "mail fill",
        "mail-forbid-fill": "mail forbid fill",
        "mail-forbid-line": "mail forbid line",
        "mail-line": "mail line",
        "mail-lock-fill": "mail lock fill",
        "mail-lock-line": "mail lock line",
        "mail-open-fill": "mail open fill",
        "mail-open-line": "mail open line",
        "mail-send-fill": "mail send fill",
        "mail-send-line": "mail send line",
        "mail-settings-fill": "mail settings fill",
        "mail-settings-line": "mail settings line",
        "mail-star-fill": "mail star fill",
        "mail-star-line": "mail star line",
        "mail-unread-fill": "mail unread fill",
        "mail-unread-line": "mail unread line",
        "mail-volume-fill": "mail volume fill",
        "mail-volume-line": "mail volume line",
        "medal-2-fill": "medal 2 fill",
        "medal-2-line": "medal 2 line",
        "medal-fill": "medal fill",
        "medal-line": "medal line",
        "megaphone-fill": "megaphone fill",
        "megaphone-line": "megaphone line",
        "pass-expired-fill": "pass expired fill",
        "pass-expired-line": "pass expired line",
        "pass-pending-fill": "pass pending fill",
        "pass-pending-line": "pass pending line",
        "pass-valid-fill": "pass valid fill",
        "pass-valid-line": "pass valid line",
        "pie-chart-2-fill": "pie chart 2 fill",
        "pie-chart-2-line": "pie chart 2 line",
        "pie-chart-box-fill": "pie chart box fill",
        "pie-chart-box-line": "pie chart box line",
        "pie-chart-fill": "pie chart fill",
        "pie-chart-line": "pie chart line",
        "presentation-fill": "presentation fill",
        "presentation-line": "presentation line",
        "printer-cloud-fill": "printer cloud fill",
        "printer-cloud-line": "printer cloud line",
        "printer-fill": "printer fill",
        "printer-line": "printer line",
        "profile-fill": "profile fill",
        "profile-line": "profile line",
        "projector-2-fill": "projector 2 fill",
        "projector-2-line": "projector 2 line",
        "projector-fill": "projector fill",
        "projector-line": "projector line",
        "record-mail-fill": "record mail fill",
        "record-mail-line": "record mail line",
        "registered-fill": "registered fill",
        "registered-line": "registered line",
        "reply-all-fill": "reply all fill",
        "reply-all-line": "reply all line",
        "reply-fill": "reply fill",
        "reply-line": "reply line",
        "send-plane-2-fill": "send plane 2 fill",
        "send-plane-2-line": "send plane 2 line",
        "send-plane-fill": "send plane fill",
        "send-plane-line": "send plane line",
        "seo-fill": "seo fill",
        "seo-line": "seo line",
        "service-fill": "service fill",
        "service-line": "service line",
        "shake-hands-fill": "shake hands fill",
        "shake-hands-line": "shake hands line",
        "slideshow-2-fill": "slideshow 2 fill",
        "slideshow-2-line": "slideshow 2 line",
        "slideshow-3-fill": "slideshow 3 fill",
        "slideshow-3-line": "slideshow 3 line",
        "slideshow-4-fill": "slideshow 4 fill",
        "slideshow-4-line": "slideshow 4 line",
        "slideshow-fill": "slideshow fill",
        "slideshow-line": "slideshow line",
        "stack-fill": "stack fill",
        "stack-line": "stack line",
        "trademark-fill": "trademark fill",
        "trademark-line": "trademark line",
        "triangular-flag-fill": "triangular flag fill",
        "triangular-flag-line": "triangular flag line",
        "verified-badge-fill": "verified badge fill",
        "verified-badge-line": "verified badge line",
        "window-2-fill": "window 2 fill",
        "window-2-line": "window 2 line",
        "window-fill": "window fill",
        "window-line": "window line",
    },
    "Communication": {
        "chat-1-fill": "chat 1 fill",
        "chat-1-line": "chat 1 line",
        "chat-2-fill": "chat 2 fill",
        "chat-2-line": "chat 2 line",
        "chat-3-fill": "chat 3 fill",
        "chat-3-line": "chat 3 line",
        "chat-4-fill": "chat 4 fill",
        "chat-4-line": "chat 4 line",
        "chat-ai-2-fill": "chat ai 2 fill",
        "chat-ai-2-line": "chat ai 2 line",
        "chat-ai-3-fill": "chat ai 3 fill",
        "chat-ai-3-line": "chat ai 3 line",
        "chat-ai-4-fill": "chat ai 4 fill",
        "chat-ai-4-line": "chat ai 4 line",
        "chat-ai-fill": "chat ai fill",
        "chat-ai-line": "chat ai line",
        "chat-check-fill": "chat check fill",
        "chat-check-line": "chat check line",
        "chat-delete-fill": "chat delete fill",
        "chat-delete-line": "chat delete line",
        "chat-download-fill": "chat download fill",
        "chat-download-line": "chat download line",
        "chat-follow-up-fill": "chat follow up fill",
        "chat-follow-up-line": "chat follow up line",
        "chat-forward-fill": "chat forward fill",
        "chat-forward-line": "chat forward line",
        "chat-heart-fill": "chat heart fill",
        "chat-heart-line": "chat heart line",
        "chat-history-fill": "chat history fill",
        "chat-history-line": "chat history line",
        "chat-new-fill": "chat new fill",
        "chat-new-line": "chat new line",
        "chat-off-fill": "chat off fill",
        "chat-off-line": "chat off line",
        "chat-poll-fill": "chat poll fill",
        "chat-poll-line": "chat poll line",
        "chat-private-fill": "chat private fill",
        "chat-private-line": "chat private line",
        "chat-quote-fill": "chat quote fill",
        "chat-quote-line": "chat quote line",
        "chat-search-fill": "chat search fill",
        "chat-search-line": "chat search line",
        "chat-settings-fill": "chat settings fill",
        "chat-settings-line": "chat settings line",
        "chat-smile-2-fill": "chat smile 2 fill",
        "chat-smile-2-line": "chat smile 2 line",
        "chat-smile-3-fill": "chat smile 3 fill",
        "chat-smile-3-line": "chat smile 3 line",
        "chat-smile-ai-3-fill": "chat smile ai 3 fill",
        "chat-smile-ai-3-line": "chat smile ai 3 line",
        "chat-smile-ai-fill": "chat smile ai fill",
        "chat-smile-ai-line": "chat smile ai line",
        "chat-smile-fill": "chat smile fill",
        "chat-smile-line": "chat smile line",
        "chat-thread-fill": "chat thread fill",
        "chat-thread-line": "chat thread line",
        "chat-unread-fill": "chat unread fill",
        "chat-unread-line": "chat unread line",
        "chat-upload-fill": "chat upload fill",
        "chat-upload-line": "chat upload line",
        "chat-voice-ai-fill": "chat voice ai fill",
        "chat-voice-ai-line": "chat voice ai line",
        "chat-voice-fill": "chat voice fill",
        "chat-voice-line": "chat voice line",
        "discuss-fill": "discuss fill",
        "discuss-line": "discuss line",
        "emoji-sticker-fill": "emoji sticker fill",
        "emoji-sticker-line": "emoji sticker line",
        "feedback-fill": "feedback fill",
        "feedback-line": "feedback line",
        "message-2-fill": "message 2 fill",
        "message-2-line": "message 2 line",
        "message-3-fill": "message 3 fill",
        "message-3-line": "message 3 line",
        "message-ai-3-fill": "message ai 3 fill",
        "message-ai-3-line": "message ai 3 line",
        "message-fill": "message fill",
        "message-line": "message line",
        "question-answer-fill": "question answer fill",
        "question-answer-line": "question answer line",
        "questionnaire-fill": "questionnaire fill",
        "questionnaire-line": "questionnaire line",
        "speak-ai-fill": "speak ai fill",
        "speak-ai-line": "speak ai line",
        "speak-fill": "speak fill",
        "speak-line": "speak line",
        "speech-to-text-fill": "speech to text fill",
        "speech-to-text-line": "speech to text line",
        "text-to-speech-fill": "text to speech fill",
        "text-to-speech-line": "text to speech line",
        "video-chat-fill": "video chat fill",
        "video-chat-line": "video chat line",
    },
    "Design": {
        "ai-generate-2-fill": "ai generate 2 fill",
        "ai-generate-2-line": "ai generate 2 line",
        "align-item-bottom-fill": "align item bottom fill",
        "align-item-bottom-line": "align item bottom line",
        "align-item-horizontal-center-fill": "align item horizontal center fill",
        "align-item-horizontal-center-line": "align item horizontal center line",
        "align-item-left-fill": "align item left fill",
        "align-item-left-line": "align item left line",
        "align-item-right-fill": "align item right fill",
        "align-item-right-line": "align item right line",
        "align-item-top-fill": "align item top fill",
        "align-item-top-line": "align item top line",
        "align-item-vertical-center-fill": "align item vertical center fill",
        "align-item-vertical-center-line": "align item vertical center line",
        "anticlockwise-2-fill": "anticlockwise 2 fill",
        "anticlockwise-2-line": "anticlockwise 2 line",
        "anticlockwise-fill": "anticlockwise fill",
        "anticlockwise-line": "anticlockwise line",
        "artboard-2-fill": "artboard 2 fill",
        "artboard-2-line": "artboard 2 line",
        "artboard-fill": "artboard fill",
        "artboard-line": "artboard line",
        "ball-pen-fill": "ball pen fill",
        "ball-pen-line": "ball pen line",
        "blur-off-fill": "blur off fill",
        "blur-off-line": "blur off line",
        "brush-2-fill": "brush 2 fill",
        "brush-2-line": "brush 2 line",
        "brush-3-fill": "brush 3 fill",
        "brush-3-line": "brush 3 line",
        "brush-4-fill": "brush 4 fill",
        "brush-4-line": "brush 4 line",
        "brush-ai-3-fill": "brush ai 3 fill",
        "brush-ai-3-line": "brush ai 3 line",
        "brush-ai-fill": "brush ai fill",
        "brush-ai-line": "brush ai line",
        "brush-fill": "brush fill",
        "brush-line": "brush line",
        "circle-fill": "circle fill",
        "circle-line": "circle line",
        "clockwise-2-fill": "clockwise 2 fill",
        "clockwise-2-line": "clockwise 2 line",
        "clockwise-fill": "clockwise fill",
        "clockwise-line": "clockwise line",
        "collage-fill": "collage fill",
        "collage-line": "collage line",
        "color-filter-ai-fill": "color filter ai fill",
        "color-filter-ai-line": "color filter ai line",
        "color-filter-fill": "color filter fill",
        "color-filter-line": "color filter line",
        "compasses-2-fill": "compasses 2 fill",
        "compasses-2-line": "compasses 2 line",
        "compasses-fill": "compasses fill",
        "compasses-line": "compasses line",
        "contrast-2-fill": "contrast 2 fill",
        "contrast-2-line": "contrast 2 line",
        "contrast-drop-2-fill": "contrast drop 2 fill",
        "contrast-drop-2-line": "contrast drop 2 line",
        "contrast-drop-fill": "contrast drop fill",
        "contrast-drop-line": "contrast drop line",
        "contrast-fill": "contrast fill",
        "contrast-line": "contrast line",
        "crop-2-fill": "crop 2 fill",
        "crop-2-line": "crop 2 line",
        "crop-fill": "crop fill",
        "crop-line": "crop line",
        "crosshair-2-fill": "crosshair 2 fill",
        "crosshair-2-line": "crosshair 2 line",
        "crosshair-fill": "crosshair fill",
        "crosshair-line": "crosshair line",
        "drag-drop-fill": "drag drop fill",
        "drag-drop-line": "drag drop line",
        "drop-fill": "drop fill",
        "drop-line": "drop line",
        "edit-2-fill": "edit 2 fill",
        "edit-2-line": "edit 2 line",
        "edit-box-fill": "edit box fill",
        "edit-box-line": "edit box line",
        "edit-circle-fill": "edit circle fill",
        "edit-circle-line": "edit circle line",
        "edit-fill": "edit fill",
        "edit-line": "edit line",
        "eraser-fill": "eraser fill",
        "eraser-line": "eraser line",
        "flip-horizontal-2-fill": "flip horizontal 2 fill",
        "flip-horizontal-2-line": "flip horizontal 2 line",
        "flip-horizontal-fill": "flip horizontal fill",
        "flip-horizontal-line": "flip horizontal line",
        "flip-vertical-2-fill": "flip vertical 2 fill",
        "flip-vertical-2-line": "flip vertical 2 line",
        "flip-vertical-fill": "flip vertical fill",
        "flip-vertical-line": "flip vertical line",
        "focus-2-fill": "focus 2 fill",
        "focus-2-line": "focus 2 line",
        "focus-3-fill": "focus 3 fill",
        "focus-3-line": "focus 3 line",
        "focus-fill": "focus fill",
        "focus-line": "focus line",
        "grid-fill": "grid fill",
        "grid-line": "grid line",
        "hammer-fill": "hammer fill",
        "hammer-line": "hammer line",
        "hexagon-fill": "hexagon fill",
        "hexagon-line": "hexagon line",
        "ink-bottle-fill": "ink bottle fill",
        "ink-bottle-line": "ink bottle line",
        "input-method-fill": "input method fill",
        "input-method-line": "input method line",
        "layout-2-fill": "layout 2 fill",
        "layout-2-line": "layout 2 line",
        "layout-3-fill": "layout 3 fill",
        "layout-3-line": "layout 3 line",
        "layout-4-fill": "layout 4 fill",
        "layout-4-line": "layout 4 line",
        "layout-5-fill": "layout 5 fill",
        "layout-5-line": "layout 5 line",
        "layout-6-fill": "layout 6 fill",
        "layout-6-line": "layout 6 line",
        "layout-bottom-2-fill": "layout bottom 2 fill",
        "layout-bottom-2-line": "layout bottom 2 line",
        "layout-bottom-fill": "layout bottom fill",
        "layout-bottom-line": "layout bottom line",
        "layout-column-fill": "layout column fill",
        "layout-column-line": "layout column line",
        "layout-fill": "layout fill",
        "layout-grid-2-fill": "layout grid 2 fill",
        "layout-grid-2-line": "layout grid 2 line",
        "layout-grid-fill": "layout grid fill",
        "layout-grid-line": "layout grid line",
        "layout-horizontal-fill": "layout horizontal fill",
        "layout-horizontal-line": "layout horizontal line",
        "layout-left-2-fill": "layout left 2 fill",
        "layout-left-2-line": "layout left 2 line",
        "layout-left-fill": "layout left fill",
        "layout-left-line": "layout left line",
        "layout-line": "layout line",
        "layout-masonry-fill": "layout masonry fill",
        "layout-masonry-line": "layout masonry line",
        "layout-right-2-fill": "layout right 2 fill",
        "layout-right-2-line": "layout right 2 line",
        "layout-right-fill": "layout right fill",
        "layout-right-line": "layout right line",
        "layout-row-fill": "layout row fill",
        "layout-row-line": "layout row line",
        "layout-top-2-fill": "layout top 2 fill",
        "layout-top-2-line": "layout top 2 line",
        "layout-top-fill": "layout top fill",
        "layout-top-line": "layout top line",
        "layout-vertical-fill": "layout vertical fill",
        "layout-vertical-line": "layout vertical line",
        "magic-fill": "magic fill",
        "magic-line": "magic line",
        "mark-pen-fill": "mark pen fill",
        "mark-pen-line": "mark pen line",
        "markup-fill": "markup fill",
        "markup-line": "markup line",
        "octagon-fill": "octagon fill",
        "octagon-line": "octagon line",
        "paint-brush-fill": "paint brush fill",
        "paint-brush-line": "paint brush line",
        "paint-fill": "paint fill",
        "paint-line": "paint line",
        "painting-ai-fill": "painting ai fill",
        "painting-ai-line": "painting ai line",
        "painting-fill": "painting fill",
        "painting-line": "painting line",
        "palette-fill": "palette fill",
        "palette-line": "palette line",
        "pantone-fill": "pantone fill",
        "pantone-line": "pantone line",
        "pen-nib-fill": "pen nib fill",
        "pen-nib-line": "pen nib line",
        "pencil-ai-2-fill": "pencil ai 2 fill",
        "pencil-ai-2-line": "pencil ai 2 line",
        "pencil-ai-fill": "pencil ai fill",
        "pencil-ai-line": "pencil ai line",
        "pencil-fill": "pencil fill",
        "pencil-line": "pencil line",
        "pencil-ruler-2-fill": "pencil ruler 2 fill",
        "pencil-ruler-2-line": "pencil ruler 2 line",
        "pencil-ruler-fill": "pencil ruler fill",
        "pencil-ruler-line": "pencil ruler line",
        "pentagon-fill": "pentagon fill",
        "pentagon-line": "pentagon line",
        "quill-pen-ai-fill": "quill pen ai fill",
        "quill-pen-ai-line": "quill pen ai line",
        "quill-pen-fill": "quill pen fill",
        "quill-pen-line": "quill pen line",
        "rectangle-fill": "rectangle fill",
        "rectangle-line": "rectangle line",
        "remix-fill": "remix fill",
        "remix-line": "remix line",
        "ruler-2-fill": "ruler 2 fill",
        "ruler-2-line": "ruler 2 line",
        "ruler-fill": "ruler fill",
        "ruler-line": "ruler line",
        "scissors-2-fill": "scissors 2 fill",
        "scissors-2-line": "scissors 2 line",
        "scissors-cut-fill": "scissors cut fill",
        "scissors-cut-line": "scissors cut line",
        "scissors-fill": "scissors fill",
        "scissors-line": "scissors line",
        "screenshot-2-fill": "screenshot 2 fill",
        "screenshot-2-line": "screenshot 2 line",
        "screenshot-fill": "screenshot fill",
        "screenshot-line": "screenshot line",
        "shadow-fill": "shadow fill",
        "shadow-line": "shadow line",
        "shape-2-fill": "shape 2 fill",
        "shape-2-line": "shape 2 line",
        "shape-fill": "shape fill",
        "shape-line": "shape line",
        "shapes-fill": "shapes fill",
        "shapes-line": "shapes line",
        "sip-fill": "sip fill",
        "sip-line": "sip line",
        "slice-fill": "slice fill",
        "slice-line": "slice line",
        "square-fill": "square fill",
        "square-line": "square line",
        "t-box-fill": "t box fill",
        "t-box-line": "t box line",
        "table-alt-fill": "table alt fill",
        "table-alt-line": "table alt line",
        "table-fill": "table fill",
        "table-line": "table line",
        "tools-fill": "tools fill",
        "tools-line": "tools line",
        "triangle-fill": "triangle fill",
        "triangle-line": "triangle line",
        "wrench-fill": "wrench fill",
        "wrench-line": "wrench line",
    },
    "Development": {
        "braces-fill": "braces fill",
        "braces-line": "braces line",
        "brackets-fill": "brackets fill",
        "brackets-line": "brackets line",
        "bug-2-fill": "bug 2 fill",
        "bug-2-line": "bug 2 line",
        "bug-fill": "bug fill",
        "bug-line": "bug line",
        "code-ai-fill": "code ai fill",
        "code-ai-line": "code ai line",
        "code-box-fill": "code box fill",
        "code-box-line": "code box line",
        "code-fill": "code fill",
        "code-line": "code line",
        "code-s-fill": "code s fill",
        "code-s-line": "code s line",
        "code-s-slash-fill": "code s slash fill",
        "code-s-slash-line": "code s slash line",
        "command-fill": "command fill",
        "command-line": "command line",
        "css3-fill": "css3 fill",
        "css3-line": "css3 line",
        "cursor-fill": "cursor fill",
        "cursor-line": "cursor line",
        "git-branch-fill": "git branch fill",
        "git-branch-line": "git branch line",
        "git-close-pull-request-fill": "git close pull request fill",
        "git-close-pull-request-line": "git close pull request line",
        "git-commit-fill": "git commit fill",
        "git-commit-line": "git commit line",
        "git-fork-fill": "git fork fill",
        "git-fork-line": "git fork line",
        "git-merge-fill": "git merge fill",
        "git-merge-line": "git merge line",
        "git-pr-draft-fill": "git pr draft fill",
        "git-pr-draft-line": "git pr draft line",
        "git-pull-request-fill": "git pull request fill",
        "git-pull-request-line": "git pull request line",
        "git-repository-commits-fill": "git repository commits fill",
        "git-repository-commits-line": "git repository commits line",
        "git-repository-fill": "git repository fill",
        "git-repository-line": "git repository line",
        "git-repository-private-fill": "git repository private fill",
        "git-repository-private-line": "git repository private line",
        "html5-fill": "html5 fill",
        "html5-line": "html5 line",
        "javascript-fill": "javascript fill",
        "javascript-line": "javascript line",
        "parentheses-fill": "parentheses fill",
        "parentheses-line": "parentheses line",
        "php-fill": "php fill",
        "php-line": "php line",
        "puzzle-2-fill": "puzzle 2 fill",
        "puzzle-2-line": "puzzle 2 line",
        "puzzle-fill": "puzzle fill",
        "puzzle-line": "puzzle line",
        "terminal-box-fill": "terminal box fill",
        "terminal-box-line": "terminal box line",
        "terminal-fill": "terminal fill",
        "terminal-line": "terminal line",
        "terminal-window-fill": "terminal window fill",
        "terminal-window-line": "terminal window line",
    },
    "Device": {
        "airplay-fill": "airplay fill",
        "airplay-line": "airplay line",
        "barcode-box-fill": "barcode box fill",
        "barcode-box-line": "barcode box line",
        "barcode-fill": "barcode fill",
        "barcode-line": "barcode line",
        "base-station-fill": "base station fill",
        "base-station-line": "base station line",
        "battery-2-charge-fill": "battery 2 charge fill",
        "battery-2-charge-line": "battery 2 charge line",
        "battery-2-fill": "battery 2 fill",
        "battery-2-line": "battery 2 line",
        "battery-charge-fill": "battery charge fill",
        "battery-charge-line": "battery charge line",
        "battery-fill": "battery fill",
        "battery-line": "battery line",
        "battery-low-fill": "battery low fill",
        "battery-low-line": "battery low line",
        "battery-saver-fill": "battery saver fill",
        "battery-saver-line": "battery saver line",
        "battery-share-fill": "battery share fill",
        "battery-share-line": "battery share line",
        "bluetooth-connect-fill": "bluetooth connect fill",
        "bluetooth-connect-line": "bluetooth connect line",
        "bluetooth-fill": "bluetooth fill",
        "bluetooth-line": "bluetooth line",
        "cast-fill": "cast fill",
        "cast-line": "cast line",
        "cellphone-fill": "cellphone fill",
        "cellphone-line": "cellphone line",
        "computer-fill": "computer fill",
        "computer-line": "computer line",
        "cpu-fill": "cpu fill",
        "cpu-line": "cpu line",
        "dashboard-2-fill": "dashboard 2 fill",
        "dashboard-2-line": "dashboard 2 line",
        "dashboard-3-fill": "dashboard 3 fill",
        "dashboard-3-line": "dashboard 3 line",
        "database-2-fill": "database 2 fill",
        "database-2-line": "database 2 line",
        "database-fill": "database fill",
        "database-line": "database line",
        "device-fill": "device fill",
        "device-line": "device line",
        "device-recover-fill": "device recover fill",
        "device-recover-line": "device recover line",
        "dual-sim-1-fill": "dual sim 1 fill",
        "dual-sim-1-line": "dual sim 1 line",
        "dual-sim-2-fill": "dual sim 2 fill",
        "dual-sim-2-line": "dual sim 2 line",
        "fingerprint-2-fill": "fingerprint 2 fill",
        "fingerprint-2-line": "fingerprint 2 line",
        "fingerprint-fill": "fingerprint fill",
        "fingerprint-line": "fingerprint line",
        "gamepad-fill": "gamepad fill",
        "gamepad-line": "gamepad line",
        "gps-fill": "gps fill",
        "gps-line": "gps line",
        "gradienter-fill": "gradienter fill",
        "gradienter-line": "gradienter line",
        "hard-drive-2-fill": "hard drive 2 fill",
        "hard-drive-2-line": "hard drive 2 line",
        "hard-drive-3-fill": "hard drive 3 fill",
        "hard-drive-3-line": "hard drive 3 line",
        "hard-drive-fill": "hard drive fill",
        "hard-drive-line": "hard drive line",
        "hotspot-fill": "hotspot fill",
        "hotspot-line": "hotspot line",
        "install-fill": "install fill",
        "install-line": "install line",
        "instance-fill": "instance fill",
        "instance-line": "instance line",
        "keyboard-box-fill": "keyboard box fill",
        "keyboard-box-line": "keyboard box line",
        "keyboard-fill": "keyboard fill",
        "keyboard-line": "keyboard line",
        "mac-fill": "mac fill",
        "mac-line": "mac line",
        "macbook-fill": "macbook fill",
        "macbook-line": "macbook line",
        "mobile-download-fill": "mobile download fill",
        "mobile-download-line": "mobile download line",
        "mouse-fill": "mouse fill",
        "mouse-line": "mouse line",
        "phone-fill": "phone fill",
        "phone-find-fill": "phone find fill",
        "phone-find-line": "phone find line",
        "phone-line": "phone line",
        "phone-lock-fill": "phone lock fill",
        "phone-lock-line": "phone lock line",
        "qr-code-fill": "qr code fill",
        "qr-code-line": "qr code line",
        "qr-scan-2-fill": "qr scan 2 fill",
        "qr-scan-2-line": "qr scan 2 line",
        "qr-scan-fill": "qr scan fill",
        "qr-scan-line": "qr scan line",
        "radar-fill": "radar fill",
        "radar-line": "radar line",
        "ram-2-fill": "ram 2 fill",
        "ram-2-line": "ram 2 line",
        "ram-fill": "ram fill",
        "ram-line": "ram line",
        "remote-control-2-fill": "remote control 2 fill",
        "remote-control-2-line": "remote control 2 line",
        "remote-control-fill": "remote control fill",
        "remote-control-line": "remote control line",
        "restart-fill": "restart fill",
        "restart-line": "restart line",
        "rfid-fill": "rfid fill",
        "rfid-line": "rfid line",
        "rotate-lock-fill": "rotate lock fill",
        "rotate-lock-line": "rotate lock line",
        "router-fill": "router fill",
        "router-line": "router line",
        "rss-fill": "rss fill",
        "rss-line": "rss line",
        "save-2-fill": "save 2 fill",
        "save-2-line": "save 2 line",
        "save-3-fill": "save 3 fill",
        "save-3-line": "save 3 line",
        "save-fill": "save fill",
        "save-line": "save line",
        "scan-2-fill": "scan 2 fill",
        "scan-2-line": "scan 2 line",
        "scan-fill": "scan fill",
        "scan-line": "scan line",
        "sd-card-fill": "sd card fill",
        "sd-card-line": "sd card line",
        "sd-card-mini-fill": "sd card mini fill",
        "sd-card-mini-line": "sd card mini line",
        "sensor-fill": "sensor fill",
        "sensor-line": "sensor line",
        "server-fill": "server fill",
        "server-line": "server line",
        "shut-down-fill": "shut down fill",
        "shut-down-line": "shut down line",
        "signal-wifi-1-fill": "signal wifi 1 fill",
        "signal-wifi-1-line": "signal wifi 1 line",
        "signal-wifi-2-fill": "signal wifi 2 fill",
        "signal-wifi-2-line": "signal wifi 2 line",
        "signal-wifi-3-fill": "signal wifi 3 fill",
        "signal-wifi-3-line": "signal wifi 3 line",
        "signal-wifi-error-fill": "signal wifi error fill",
        "signal-wifi-error-line": "signal wifi error line",
        "signal-wifi-fill": "signal wifi fill",
        "signal-wifi-line": "signal wifi line",
        "signal-wifi-off-fill": "signal wifi off fill",
        "signal-wifi-off-line": "signal wifi off line",
        "sim-card-2-fill": "sim card 2 fill",
        "sim-card-2-line": "sim card 2 line",
        "sim-card-fill": "sim card fill",
        "sim-card-line": "sim card line",
        "smartphone-fill": "smartphone fill",
        "smartphone-line": "smartphone line",
        "tablet-fill": "tablet fill",
        "tablet-line": "tablet line",
        "tv-2-fill": "tv 2 fill",
        "tv-2-line": "tv 2 line",
        "tv-fill": "tv fill",
        "tv-line": "tv line",
        "u-disk-fill": "u disk fill",
        "u-disk-line": "u disk line",
        "uninstall-fill": "uninstall fill",
        "uninstall-line": "uninstall line",
        "usb-fill": "usb fill",
        "usb-line": "usb line",
        "wifi-fill": "wifi fill",
        "wifi-line": "wifi line",
        "wifi-off-fill": "wifi off fill",
        "wifi-off-line": "wifi off line",
        "wireless-charging-fill": "wireless charging fill",
        "wireless-charging-line": "wireless charging line",
    },
    "Document": {
        "article-fill": "article fill",
        "article-line": "article line",
        "bill-fill": "bill fill",
        "bill-line": "bill line",
        "book-2-fill": "book 2 fill",
        "book-2-line": "book 2 line",
        "book-3-fill": "book 3 fill",
        "book-3-line": "book 3 line",
        "book-ai-fill": "book ai fill",
        "book-ai-line": "book ai line",
        "book-fill": "book fill",
        "book-line": "book line",
        "book-marked-fill": "book marked fill",
        "book-marked-line": "book marked line",
        "book-open-fill": "book open fill",
        "book-open-line": "book open line",
        "book-read-fill": "book read fill",
        "book-read-line": "book read line",
        "booklet-fill": "booklet fill",
        "booklet-line": "booklet line",
        "clipboard-fill": "clipboard fill",
        "clipboard-line": "clipboard line",
        "contacts-book-2-fill": "contacts book 2 fill",
        "contacts-book-2-line": "contacts book 2 line",
        "contacts-book-3-fill": "contacts book 3 fill",
        "contacts-book-3-line": "contacts book 3 line",
        "contacts-book-fill": "contacts book fill",
        "contacts-book-line": "contacts book line",
        "contacts-book-upload-fill": "contacts book upload fill",
        "contacts-book-upload-line": "contacts book upload line",
        "contract-fill": "contract fill",
        "contract-line": "contract line",
        "draft-fill": "draft fill",
        "draft-line": "draft line",
        "file-2-fill": "file 2 fill",
        "file-2-line": "file 2 line",
        "file-3-fill": "file 3 fill",
        "file-3-line": "file 3 line",
        "file-4-fill": "file 4 fill",
        "file-4-line": "file 4 line",
        "file-add-fill": "file add fill",
        "file-add-line": "file add line",
        "file-ai-2-fill": "file ai 2 fill",
        "file-ai-2-line": "file ai 2 line",
        "file-ai-fill": "file ai fill",
        "file-ai-line": "file ai line",
        "file-chart-2-fill": "file chart 2 fill",
        "file-chart-2-line": "file chart 2 line",
        "file-chart-fill": "file chart fill",
        "file-chart-line": "file chart line",
        "file-check-fill": "file check fill",
        "file-check-line": "file check line",
        "file-close-fill": "file close fill",
        "file-close-line": "file close line",
        "file-cloud-fill": "file cloud fill",
        "file-cloud-line": "file cloud line",
        "file-code-fill": "file code fill",
        "file-code-line": "file code line",
        "file-copy-2-fill": "file copy 2 fill",
        "file-copy-2-line": "file copy 2 line",
        "file-copy-fill": "file copy fill",
        "file-copy-line": "file copy line",
        "file-damage-fill": "file damage fill",
        "file-damage-line": "file damage line",
        "file-download-fill": "file download fill",
        "file-download-line": "file download line",
        "file-edit-fill": "file edit fill",
        "file-edit-line": "file edit line",
        "file-excel-2-fill": "file excel 2 fill",
        "file-excel-2-line": "file excel 2 line",
        "file-excel-fill": "file excel fill",
        "file-excel-line": "file excel line",
        "file-fill": "file fill",
        "file-forbid-fill": "file forbid fill",
        "file-forbid-line": "file forbid line",
        "file-gif-fill": "file gif fill",
        "file-gif-line": "file gif line",
        "file-history-fill": "file history fill",
        "file-history-line": "file history line",
        "file-hwp-fill": "file hwp fill",
        "file-hwp-line": "file hwp line",
        "file-image-fill": "file image fill",
        "file-image-line": "file image line",
        "file-info-fill": "file info fill",
        "file-info-line": "file info line",
        "file-line": "file line",
        "file-list-2-fill": "file list 2 fill",
        "file-list-2-line": "file list 2 line",
        "file-list-3-fill": "file list 3 fill",
        "file-list-3-line": "file list 3 line",
        "file-list-fill": "file list fill",
        "file-list-line": "file list line",
        "file-lock-fill": "file lock fill",
        "file-lock-line": "file lock line",
        "file-marked-fill": "file marked fill",
        "file-marked-line": "file marked line",
        "file-music-fill": "file music fill",
        "file-music-line": "file music line",
        "file-paper-2-fill": "file paper 2 fill",
        "file-paper-2-line": "file paper 2 line",
        "file-paper-fill": "file paper fill",
        "file-paper-line": "file paper line",
        "file-pdf-2-fill": "file pdf 2 fill",
        "file-pdf-2-line": "file pdf 2 line",
        "file-pdf-fill": "file pdf fill",
        "file-pdf-line": "file pdf line",
        "file-ppt-2-fill": "file ppt 2 fill",
        "file-ppt-2-line": "file ppt 2 line",
        "file-ppt-fill": "file ppt fill",
        "file-ppt-line": "file ppt line",
        "file-reduce-fill": "file reduce fill",
        "file-reduce-line": "file reduce line",
        "file-search-fill": "file search fill",
        "file-search-line": "file search line",
        "file-settings-fill": "file settings fill",
        "file-settings-line": "file settings line",
        "file-shield-2-fill": "file shield 2 fill",
        "file-shield-2-line": "file shield 2 line",
        "file-shield-fill": "file shield fill",
        "file-shield-line": "file shield line",
        "file-shred-fill": "file shred fill",
        "file-shred-line": "file shred line",
        "file-text-fill": "file text fill",
        "file-text-line": "file text line",
        "file-transfer-fill": "file transfer fill",
        "file-transfer-line": "file transfer line",
        "file-unknow-fill": "file unknow fill",
        "file-unknow-line": "file unknow line",
        "file-upload-fill": "file upload fill",
        "file-upload-line": "file upload line",
        "file-user-fill": "file user fill",
        "file-user-line": "file user line",
        "file-video-fill": "file video fill",
        "file-video-line": "file video line",
        "file-warning-fill": "file warning fill",
        "file-warning-line": "file warning line",
        "file-word-2-fill": "file word 2 fill",
        "file-word-2-line": "file word 2 line",
        "file-word-fill": "file word fill",
        "file-word-line": "file word line",
        "file-zip-fill": "file zip fill",
        "file-zip-line": "file zip line",
        "folder-2-fill": "folder 2 fill",
        "folder-2-line": "folder 2 line",
        "folder-3-fill": "folder 3 fill",
        "folder-3-line": "folder 3 line",
        "folder-4-fill": "folder 4 fill",
        "folder-4-line": "folder 4 line",
        "folder-5-fill": "folder 5 fill",
        "folder-5-line": "folder 5 line",
        "folder-6-fill": "folder 6 fill",
        "folder-6-line": "folder 6 line",
        "folder-add-fill": "folder add fill",
        "folder-add-line": "folder add line",
        "folder-chart-2-fill": "folder chart 2 fill",
        "folder-chart-2-line": "folder chart 2 line",
        "folder-chart-fill": "folder chart fill",
        "folder-chart-line": "folder chart line",
        "folder-check-fill": "folder check fill",
        "folder-check-line": "folder check line",
        "folder-close-fill": "folder close fill",
        "folder-close-line": "folder close line",
        "folder-cloud-fill": "folder cloud fill",
        "folder-cloud-line": "folder cloud line",
        "folder-download-fill": "folder download fill",
        "folder-download-line": "folder download line",
        "folder-fill": "folder fill",
        "folder-forbid-fill": "folder forbid fill",
        "folder-forbid-line": "folder forbid line",
        "folder-history-fill": "folder history fill",
        "folder-history-line": "folder history line",
        "folder-image-fill": "folder image fill",
        "folder-image-line": "folder image line",
        "folder-info-fill": "folder info fill",
        "folder-info-line": "folder info line",
        "folder-keyhole-fill": "folder keyhole fill",
        "folder-keyhole-line": "folder keyhole line",
        "folder-line": "folder line",
        "folder-lock-fill": "folder lock fill",
        "folder-lock-line": "folder lock line",
        "folder-music-fill": "folder music fill",
        "folder-music-line": "folder music line",
        "folder-open-fill": "folder open fill",
        "folder-open-line": "folder open line",
        "folder-received-fill": "folder received fill",
        "folder-received-line": "folder received line",
        "folder-reduce-fill": "folder reduce fill",
        "folder-reduce-line": "folder reduce line",
        "folder-settings-fill": "folder settings fill",
        "folder-settings-line": "folder settings line",
        "folder-shared-fill": "folder shared fill",
        "folder-shared-line": "folder shared line",
        "folder-shield-2-fill": "folder shield 2 fill",
        "folder-shield-2-line": "folder shield 2 line",
        "folder-shield-fill": "folder shield fill",
        "folder-shield-line": "folder shield line",
        "folder-transfer-fill": "folder transfer fill",
        "folder-transfer-line": "folder transfer line",
        "folder-unknow-fill": "folder unknow fill",
        "folder-unknow-line": "folder unknow line",
        "folder-upload-fill": "folder upload fill",
        "folder-upload-line": "folder upload line",
        "folder-user-fill": "folder user fill",
        "folder-user-line": "folder user line",
        "folder-video-fill": "folder video fill",
        "folder-video-line": "folder video line",
        "folder-warning-fill": "folder warning fill",
        "folder-warning-line": "folder warning line",
        "folder-zip-fill": "folder zip fill",
        "folder-zip-line": "folder zip line",
        "folders-fill": "folders fill",
        "folders-line": "folders line",
        "keynote-fill": "keynote fill",
        "keynote-line": "keynote line",
        "markdown-fill": "markdown fill",
        "markdown-line": "markdown line",
        "news-fill": "news fill",
        "news-line": "news line",
        "newspaper-fill": "newspaper fill",
        "newspaper-line": "newspaper line",
        "numbers-fill": "numbers fill",
        "numbers-line": "numbers line",
        "pages-fill": "pages fill",
        "pages-line": "pages line",
        "receipt-fill": "receipt fill",
        "receipt-line": "receipt line",
        "sticky-note-2-fill": "sticky note 2 fill",
        "sticky-note-2-line": "sticky note 2 line",
        "sticky-note-add-fill": "sticky note add fill",
        "sticky-note-add-line": "sticky note add line",
        "sticky-note-fill": "sticky note fill",
        "sticky-note-line": "sticky note line",
        "survey-fill": "survey fill",
        "survey-line": "survey line",
        "task-fill": "task fill",
        "task-line": "task line",
        "todo-fill": "todo fill",
        "todo-line": "todo line",
    },
    "Editor": {
        "a-b": "a b",
        "ai-generate-2": "ai generate 2",
        "ai-generate-text": "ai generate text",
        "ai-generate": "ai generate",
        "ai": "ai",
        "align-bottom": "align bottom",
        "align-center": "align center",
        "align-justify": "align justify",
        "align-left": "align left",
        "align-right": "align right",
        "align-top": "align top",
        "align-vertically": "align vertically",
        "asterisk": "asterisk",
        "attachment-2": "attachment 2",
        "bold": "bold",
        "bring-forward": "bring forward",
        "bring-to-front": "bring to front",
        "calendar-view": "calendar view",
        "carousel-view": "carousel view",
        "code-block": "code block",
        "code-view": "code view",
        "custom-size": "custom size",
        "delete-column": "delete column",
        "delete-row": "delete row",
        "double-quotes-l": "double quotes l",
        "double-quotes-r": "double quotes r",
        "draggable": "draggable",
        "dropdown-list": "dropdown list",
        "emphasis-cn": "emphasis cn",
        "emphasis": "emphasis",
        "english-input": "english input",
        "flow-chart": "flow chart",
        "focus-mode": "focus mode",
        "font-color": "font color",
        "font-family": "font family",
        "font-mono": "font mono",
        "font-sans-serif": "font sans serif",
        "font-sans": "font sans",
        "font-size-2": "font size 2",
        "font-size-ai": "font size ai",
        "font-size": "font size",
        "format-clear": "format clear",
        "formula": "formula",
        "functions": "functions",
        "gallery-view-2": "gallery view 2",
        "gallery-view": "gallery view",
        "h-1": "h 1",
        "h-2": "h 2",
        "h-3": "h 3",
        "h-4": "h 4",
        "h-5": "h 5",
        "h-6": "h 6",
        "hand": "hand",
        "hashtag": "hashtag",
        "heading": "heading",
        "indent-decrease": "indent decrease",
        "indent-increase": "indent increase",
        "info-i": "info i",
        "input-cursor-move": "input cursor move",
        "input-field": "input field",
        "insert-column-left": "insert column left",
        "insert-column-right": "insert column right",
        "insert-row-bottom": "insert row bottom",
        "insert-row-top": "insert row top",
        "italic": "italic",
        "kanban-view-2": "kanban view 2",
        "kanban-view": "kanban view",
        "letter-spacing-2": "letter spacing 2",
        "line-height-2": "line height 2",
        "line-height": "line height",
        "link-m": "link m",
        "link-unlink-m": "link unlink m",
        "link-unlink": "link unlink",
        "link": "link",
        "list-check-2": "list check 2",
        "list-check-3": "list check 3",
        "list-check": "list check",
        "list-indefinite": "list indefinite",
        "list-ordered-2": "list ordered 2",
        "list-ordered": "list ordered",
        "list-radio": "list radio",
        "list-unordered": "list unordered",
        "list-view": "list view",
        "merge-cells-horizontal": "merge cells horizontal",
        "merge-cells-vertical": "merge cells vertical",
        "mind-map": "mind map",
        "node-tree": "node tree",
        "number-0": "number 0",
        "number-1": "number 1",
        "number-2": "number 2",
        "number-3": "number 3",
        "number-4": "number 4",
        "number-5": "number 5",
        "number-6": "number 6",
        "number-7": "number 7",
        "number-8": "number 8",
        "number-9": "number 9",
        "omega": "omega",
        "organization-chart": "organization chart",
        "overline": "overline",
        "page-separator": "page separator",
        "paragraph": "paragraph",
        "pinyin-input": "pinyin input",
        "question-mark": "question mark",
        "quote-text": "quote text",
        "rounded-corner": "rounded corner",
        "send-backward": "send backward",
        "send-to-back": "send to back",
        "separator": "separator",
        "single-quotes-l": "single quotes l",
        "single-quotes-r": "single quotes r",
        "sketching": "sketching",
        "slash-commands-2": "slash commands 2",
        "slash-commands": "slash commands",
        "slideshow-view": "slideshow view",
        "sort-alphabet-asc": "sort alphabet asc",
        "sort-alphabet-desc": "sort alphabet desc",
        "sort-asc": "sort asc",
        "sort-desc": "sort desc",
        "sort-number-asc": "sort number asc",
        "sort-number-desc": "sort number desc",
        "space": "space",
        "split-cells-horizontal": "split cells horizontal",
        "split-cells-vertical": "split cells vertical",
        "square-root": "square root",
        "stacked-view": "stacked view",
        "strikethrough-2": "strikethrough 2",
        "strikethrough": "strikethrough",
        "subscript-2": "subscript 2",
        "subscript": "subscript",
        "superscript-2": "superscript 2",
        "superscript": "superscript",
        "table-2": "table 2",
        "table-3": "table 3",
        "table-view": "table view",
        "text-block": "text block",
        "text-direction-l": "text direction l",
        "text-direction-r": "text direction r",
        "text-snippet": "text snippet",
        "text-spacing": "text spacing",
        "text-wrap": "text wrap",
        "text": "text",
        "timeline-view": "timeline view",
        "translate-2": "translate 2",
        "translate-ai-2": "translate ai 2",
        "translate-ai": "translate ai",
        "translate": "translate",
        "underline": "underline",
        "wubi-input": "wubi input",
    },
    "Finance": {
        "24-hours-fill": "24 hours fill",
        "24-hours-line": "24 hours line",
        "auction-fill": "auction fill",
        "auction-line": "auction line",
        "bank-card-2-fill": "bank card 2 fill",
        "bank-card-2-line": "bank card 2 line",
        "bank-card-fill": "bank card fill",
        "bank-card-line": "bank card line",
        "bit-coin-fill": "bit coin fill",
        "bit-coin-line": "bit coin line",
        "bnb-fill": "bnb fill",
        "bnb-line": "bnb line",
        "btc-fill": "btc fill",
        "btc-line": "btc line",
        "cash-fill": "cash fill",
        "cash-line": "cash line",
        "coin-fill": "coin fill",
        "coin-line": "coin line",
        "coins-fill": "coins fill",
        "coins-line": "coins line",
        "copper-coin-fill": "copper coin fill",
        "copper-coin-line": "copper coin line",
        "copper-diamond-fill": "copper diamond fill",
        "copper-diamond-line": "copper diamond line",
        "coupon-2-fill": "coupon 2 fill",
        "coupon-2-line": "coupon 2 line",
        "coupon-3-fill": "coupon 3 fill",
        "coupon-3-line": "coupon 3 line",
        "coupon-4-fill": "coupon 4 fill",
        "coupon-4-line": "coupon 4 line",
        "coupon-5-fill": "coupon 5 fill",
        "coupon-5-line": "coupon 5 line",
        "coupon-fill": "coupon fill",
        "coupon-line": "coupon line",
        "currency-fill": "currency fill",
        "currency-line": "currency line",
        "diamond-fill": "diamond fill",
        "diamond-line": "diamond line",
        "diamond-ring-fill": "diamond ring fill",
        "diamond-ring-line": "diamond ring line",
        "discount-percent-fill": "discount percent fill",
        "discount-percent-line": "discount percent line",
        "eth-fill": "eth fill",
        "eth-line": "eth line",
        "exchange-2-fill": "exchange 2 fill",
        "exchange-2-line": "exchange 2 line",
        "exchange-box-fill": "exchange box fill",
        "exchange-box-line": "exchange box line",
        "exchange-cny-fill": "exchange cny fill",
        "exchange-cny-line": "exchange cny line",
        "exchange-dollar-fill": "exchange dollar fill",
        "exchange-dollar-line": "exchange dollar line",
        "exchange-fill": "exchange fill",
        "exchange-funds-fill": "exchange funds fill",
        "exchange-funds-line": "exchange funds line",
        "exchange-line": "exchange line",
        "funds-box-fill": "funds box fill",
        "funds-box-line": "funds box line",
        "funds-fill": "funds fill",
        "funds-line": "funds line",
        "gift-2-fill": "gift 2 fill",
        "gift-2-line": "gift 2 line",
        "gift-fill": "gift fill",
        "gift-line": "gift line",
        "hand-coin-fill": "hand coin fill",
        "hand-coin-line": "hand coin line",
        "hand-heart-fill": "hand heart fill",
        "hand-heart-line": "hand heart line",
        "increase-decrease-fill": "increase decrease fill",
        "increase-decrease-line": "increase decrease line",
        "jewelry-fill": "jewelry fill",
        "jewelry-line": "jewelry line",
        "money-cny-box-fill": "money cny box fill",
        "money-cny-box-line": "money cny box line",
        "money-cny-circle-fill": "money cny circle fill",
        "money-cny-circle-line": "money cny circle line",
        "money-dollar-box-fill": "money dollar box fill",
        "money-dollar-box-line": "money dollar box line",
        "money-dollar-circle-fill": "money dollar circle fill",
        "money-dollar-circle-line": "money dollar circle line",
        "money-euro-box-fill": "money euro box fill",
        "money-euro-box-line": "money euro box line",
        "money-euro-circle-fill": "money euro circle fill",
        "money-euro-circle-line": "money euro circle line",
        "money-pound-box-fill": "money pound box fill",
        "money-pound-box-line": "money pound box line",
        "money-pound-circle-fill": "money pound circle fill",
        "money-pound-circle-line": "money pound circle line",
        "money-rupee-circle-fill": "money rupee circle fill",
        "money-rupee-circle-line": "money rupee circle line",
        "nft-fill": "nft fill",
        "nft-line": "nft line",
        "no-credit-card-fill": "no credit card fill",
        "no-credit-card-line": "no credit card line",
        "p2p-fill": "p2p fill",
        "p2p-line": "p2p line",
        "percent-fill": "percent fill",
        "percent-line": "percent line",
        "price-tag-2-fill": "price tag 2 fill",
        "price-tag-2-line": "price tag 2 line",
        "price-tag-3-fill": "price tag 3 fill",
        "price-tag-3-line": "price tag 3 line",
        "price-tag-fill": "price tag fill",
        "price-tag-line": "price tag line",
        "red-packet-fill": "red packet fill",
        "red-packet-line": "red packet line",
        "refund-2-fill": "refund 2 fill",
        "refund-2-line": "refund 2 line",
        "refund-fill": "refund fill",
        "refund-line": "refund line",
        "safe-2-fill": "safe 2 fill",
        "safe-2-line": "safe 2 line",
        "safe-3-fill": "safe 3 fill",
        "safe-3-line": "safe 3 line",
        "safe-fill": "safe fill",
        "safe-line": "safe line",
        "secure-payment-fill": "secure payment fill",
        "secure-payment-line": "secure payment line",
        "shopping-bag-2-fill": "shopping bag 2 fill",
        "shopping-bag-2-line": "shopping bag 2 line",
        "shopping-bag-3-fill": "shopping bag 3 fill",
        "shopping-bag-3-line": "shopping bag 3 line",
        "shopping-bag-4-fill": "shopping bag 4 fill",
        "shopping-bag-4-line": "shopping bag 4 line",
        "shopping-bag-fill": "shopping bag fill",
        "shopping-bag-line": "shopping bag line",
        "shopping-basket-2-fill": "shopping basket 2 fill",
        "shopping-basket-2-line": "shopping basket 2 line",
        "shopping-basket-fill": "shopping basket fill",
        "shopping-basket-line": "shopping basket line",
        "shopping-cart-2-fill": "shopping cart 2 fill",
        "shopping-cart-2-line": "shopping cart 2 line",
        "shopping-cart-fill": "shopping cart fill",
        "shopping-cart-line": "shopping cart line",
        "stock-fill": "stock fill",
        "stock-line": "stock line",
        "swap-2-fill": "swap 2 fill",
        "swap-2-line": "swap 2 line",
        "swap-3-fill": "swap 3 fill",
        "swap-3-line": "swap 3 line",
        "swap-box-fill": "swap box fill",
        "swap-box-line": "swap box line",
        "swap-fill": "swap fill",
        "swap-line": "swap line",
        "ticket-2-fill": "ticket 2 fill",
        "ticket-2-line": "ticket 2 line",
        "ticket-fill": "ticket fill",
        "ticket-line": "ticket line",
        "token-swap-fill": "token swap fill",
        "token-swap-line": "token swap line",
        "trophy-fill": "trophy fill",
        "trophy-line": "trophy line",
        "vip-crown-2-fill": "vip crown 2 fill",
        "vip-crown-2-line": "vip crown 2 line",
        "vip-crown-fill": "vip crown fill",
        "vip-crown-line": "vip crown line",
        "vip-diamond-fill": "vip diamond fill",
        "vip-diamond-line": "vip diamond line",
        "vip-fill": "vip fill",
        "vip-line": "vip line",
        "wallet-2-fill": "wallet 2 fill",
        "wallet-2-line": "wallet 2 line",
        "wallet-3-fill": "wallet 3 fill",
        "wallet-3-line": "wallet 3 line",
        "wallet-fill": "wallet fill",
        "wallet-line": "wallet line",
        "water-flash-fill": "water flash fill",
        "water-flash-line": "water flash line",
        "xrp-fill": "xrp fill",
        "xrp-line": "xrp line",
        "xtz-fill": "xtz fill",
        "xtz-line": "xtz line",
    },
    "Food": {
        "beer-fill": "beer fill",
        "beer-line": "beer line",
        "bowl-fill": "bowl fill",
        "bowl-line": "bowl line",
        "bread-fill": "bread fill",
        "bread-line": "bread line",
        "cake-2-fill": "cake 2 fill",
        "cake-2-line": "cake 2 line",
        "cake-3-fill": "cake 3 fill",
        "cake-3-line": "cake 3 line",
        "cake-fill": "cake fill",
        "cake-line": "cake line",
        "cup-fill": "cup fill",
        "cup-line": "cup line",
        "drinks-2-fill": "drinks 2 fill",
        "drinks-2-line": "drinks 2 line",
        "drinks-fill": "drinks fill",
        "drinks-line": "drinks line",
        "goblet-2-fill": "goblet 2 fill",
        "goblet-2-line": "goblet 2 line",
        "goblet-broken-fill": "goblet broken fill",
        "goblet-broken-line": "goblet broken line",
        "goblet-fill": "goblet fill",
        "goblet-line": "goblet line",
        "knife-blood-fill": "knife blood fill",
        "knife-blood-line": "knife blood line",
        "knife-fill": "knife fill",
        "knife-line": "knife line",
        "restaurant-2-fill": "restaurant 2 fill",
        "restaurant-2-line": "restaurant 2 line",
        "restaurant-fill": "restaurant fill",
        "restaurant-line": "restaurant line",
    },
    "Health & Medical": {
        "aed-electrodes-fill": "aed electrodes fill",
        "aed-electrodes-line": "aed electrodes line",
        "aed-fill": "aed fill",
        "aed-line": "aed line",
        "atom-fill": "atom fill",
        "atom-line": "atom line",
        "brain-2-fill": "brain 2 fill",
        "brain-2-line": "brain 2 line",
        "brain-3-fill": "brain 3 fill",
        "brain-3-line": "brain 3 line",
        "brain-ai-3-fill": "brain ai 3 fill",
        "brain-ai-3-line": "brain ai 3 line",
        "brain-fill": "brain fill",
        "brain-line": "brain line",
        "capsule-fill": "capsule fill",
        "capsule-line": "capsule line",
        "dislike-fill": "dislike fill",
        "dislike-line": "dislike line",
        "dna-fill": "dna fill",
        "dna-line": "dna line",
        "dossier-fill": "dossier fill",
        "dossier-line": "dossier line",
        "dropper-fill": "dropper fill",
        "dropper-line": "dropper line",
        "empathize-fill": "empathize fill",
        "empathize-line": "empathize line",
        "first-aid-kit-fill": "first aid kit fill",
        "first-aid-kit-line": "first aid kit line",
        "flask-fill": "flask fill",
        "flask-line": "flask line",
        "hand-sanitizer-fill": "hand sanitizer fill",
        "hand-sanitizer-line": "hand sanitizer line",
        "health-book-fill": "health book fill",
        "health-book-line": "health book line",
        "heart-2-fill": "heart 2 fill",
        "heart-2-line": "heart 2 line",
        "heart-3-fill": "heart 3 fill",
        "heart-3-line": "heart 3 line",
        "heart-add-2-fill": "heart add 2 fill",
        "heart-add-2-line": "heart add 2 line",
        "heart-add-fill": "heart add fill",
        "heart-add-line": "heart add line",
        "heart-fill": "heart fill",
        "heart-line": "heart line",
        "heart-pulse-fill": "heart pulse fill",
        "heart-pulse-line": "heart pulse line",
        "hearts-fill": "hearts fill",
        "hearts-line": "hearts line",
        "infrared-thermometer-fill": "infrared thermometer fill",
        "infrared-thermometer-line": "infrared thermometer line",
        "lungs-fill": "lungs fill",
        "lungs-line": "lungs line",
        "medicine-bottle-fill": "medicine bottle fill",
        "medicine-bottle-line": "medicine bottle line",
        "mental-health-fill": "mental health fill",
        "mental-health-line": "mental health line",
        "microscope-fill": "microscope fill",
        "microscope-line": "microscope line",
        "nurse-fill": "nurse fill",
        "nurse-line": "nurse line",
        "psychotherapy-fill": "psychotherapy fill",
        "psychotherapy-line": "psychotherapy line",
        "pulse-ai-fill": "pulse ai fill",
        "pulse-ai-line": "pulse ai line",
        "pulse-fill": "pulse fill",
        "pulse-line": "pulse line",
        "rest-time-fill": "rest time fill",
        "rest-time-line": "rest time line",
        "stethoscope-fill": "stethoscope fill",
        "stethoscope-line": "stethoscope line",
        "surgical-mask-fill": "surgical mask fill",
        "surgical-mask-line": "surgical mask line",
        "syringe-fill": "syringe fill",
        "syringe-line": "syringe line",
        "test-tube-fill": "test tube fill",
        "test-tube-line": "test tube line",
        "thermometer-fill": "thermometer fill",
        "thermometer-line": "thermometer line",
        "virus-fill": "virus fill",
        "virus-line": "virus line",
        "zzz-fill": "zzz fill",
        "zzz-line": "zzz line",
    },
    "Logos": {
        "alibaba-cloud-fill": "alibaba cloud fill",
        "alibaba-cloud-line": "alibaba cloud line",
        "alipay-fill": "alipay fill",
        "alipay-line": "alipay line",
        "amazon-fill": "amazon fill",
        "amazon-line": "amazon line",
        "android-fill": "android fill",
        "android-line": "android line",
        "angularjs-fill": "angularjs fill",
        "angularjs-line": "angularjs line",
        "anthropic-fill": "anthropic fill",
        "anthropic-line": "anthropic line",
        "app-store-fill": "app store fill",
        "app-store-line": "app store line",
        "apple-fill": "apple fill",
        "apple-line": "apple line",
        "baidu-fill": "baidu fill",
        "baidu-line": "baidu line",
        "bard-fill": "bard fill",
        "bard-line": "bard line",
        "behance-fill": "behance fill",
        "behance-line": "behance line",
        "bilibili-fill": "bilibili fill",
        "bilibili-line": "bilibili line",
        "blender-fill": "blender fill",
        "blender-line": "blender line",
        "blogger-fill": "blogger fill",
        "blogger-line": "blogger line",
        "bluesky-fill": "bluesky fill",
        "bluesky-line": "bluesky line",
        "bootstrap-fill": "bootstrap fill",
        "bootstrap-line": "bootstrap line",
        "centos-fill": "centos fill",
        "centos-line": "centos line",
        "chrome-fill": "chrome fill",
        "chrome-line": "chrome line",
        "claude-fill": "claude fill",
        "claude-line": "claude line",
        "codepen-fill": "codepen fill",
        "codepen-line": "codepen line",
        "copilot-fill": "copilot fill",
        "copilot-line": "copilot line",
        "coreos-fill": "coreos fill",
        "coreos-line": "coreos line",
        "deepseek-fill": "deepseek fill",
        "deepseek-line": "deepseek line",
        "dingding-fill": "dingding fill",
        "dingding-line": "dingding line",
        "discord-fill": "discord fill",
        "discord-line": "discord line",
        "disqus-fill": "disqus fill",
        "disqus-line": "disqus line",
        "douban-fill": "douban fill",
        "douban-line": "douban line",
        "dribbble-fill": "dribbble fill",
        "dribbble-line": "dribbble line",
        "drive-fill": "drive fill",
        "drive-line": "drive line",
        "dropbox-fill": "dropbox fill",
        "dropbox-line": "dropbox line",
        "edge-fill": "edge fill",
        "edge-line": "edge line",
        "edge-new-fill": "edge new fill",
        "edge-new-line": "edge new line",
        "evernote-fill": "evernote fill",
        "evernote-line": "evernote line",
        "facebook-box-fill": "facebook box fill",
        "facebook-box-line": "facebook box line",
        "facebook-circle-fill": "facebook circle fill",
        "facebook-circle-line": "facebook circle line",
        "facebook-fill": "facebook fill",
        "facebook-line": "facebook line",
        "fediverse-fill": "fediverse fill",
        "fediverse-line": "fediverse line",
        "figma-fill": "figma fill",
        "figma-line": "figma line",
        "finder-fill": "finder fill",
        "finder-line": "finder line",
        "firebase-fill": "firebase fill",
        "firebase-line": "firebase line",
        "firefox-browser-fill": "firefox browser fill",
        "firefox-browser-line": "firefox browser line",
        "firefox-fill": "firefox fill",
        "firefox-line": "firefox line",
        "flickr-fill": "flickr fill",
        "flickr-line": "flickr line",
        "flutter-fill": "flutter fill",
        "flutter-line": "flutter line",
        "friendica-fill": "friendica fill",
        "friendica-line": "friendica line",
        "gatsby-fill": "gatsby fill",
        "gatsby-line": "gatsby line",
        "gemini-fill": "gemini fill",
        "gemini-line": "gemini line",
        "github-fill": "github fill",
        "github-line": "github line",
        "gitlab-fill": "gitlab fill",
        "gitlab-line": "gitlab line",
        "google-fill": "google fill",
        "google-line": "google line",
        "google-play-fill": "google play fill",
        "google-play-line": "google play line",
        "honor-of-kings-fill": "honor of kings fill",
        "honor-of-kings-line": "honor of kings line",
        "ie-fill": "ie fill",
        "ie-line": "ie line",
        "instagram-fill": "instagram fill",
        "instagram-line": "instagram line",
        "invision-fill": "invision fill",
        "invision-line": "invision line",
        "java-fill": "java fill",
        "java-line": "java line",
        "kakao-talk-fill": "kakao talk fill",
        "kakao-talk-line": "kakao talk line",
        "kick-fill": "kick fill",
        "kick-line": "kick line",
        "line-fill": "line fill",
        "line-line": "line line",
        "linkedin-box-fill": "linkedin box fill",
        "linkedin-box-line": "linkedin box line",
        "linkedin-fill": "linkedin fill",
        "linkedin-line": "linkedin line",
        "mastercard-fill": "mastercard fill",
        "mastercard-line": "mastercard line",
        "mastodon-fill": "mastodon fill",
        "mastodon-line": "mastodon line",
        "medium-fill": "medium fill",
        "medium-line": "medium line",
        "messenger-fill": "messenger fill",
        "messenger-line": "messenger line",
        "meta-fill": "meta fill",
        "meta-line": "meta line",
        "microsoft-fill": "microsoft fill",
        "microsoft-line": "microsoft line",
        "microsoft-loop-fill": "microsoft loop fill",
        "microsoft-loop-line": "microsoft loop line",
        "mini-program-fill": "mini program fill",
        "mini-program-line": "mini program line",
        "mixtral-fill": "mixtral fill",
        "mixtral-line": "mixtral line",
        "netease-cloud-music-fill": "netease cloud music fill",
        "netease-cloud-music-line": "netease cloud music line",
        "netflix-fill": "netflix fill",
        "netflix-line": "netflix line",
        "nextjs-fill": "nextjs fill",
        "nextjs-line": "nextjs line",
        "nodejs-fill": "nodejs fill",
        "nodejs-line": "nodejs line",
        "notion-fill": "notion fill",
        "notion-line": "notion line",
        "npmjs-fill": "npmjs fill",
        "npmjs-line": "npmjs line",
        "open-source-fill": "open source fill",
        "open-source-line": "open source line",
        "openai-fill": "openai fill",
        "openai-line": "openai line",
        "openbase-fill": "openbase fill",
        "openbase-line": "openbase line",
        "opera-fill": "opera fill",
        "opera-line": "opera line",
        "patreon-fill": "patreon fill",
        "patreon-line": "patreon line",
        "paypal-fill": "paypal fill",
        "paypal-line": "paypal line",
        "perplexity-fill": "perplexity fill",
        "perplexity-line": "perplexity line",
        "pinterest-fill": "pinterest fill",
        "pinterest-line": "pinterest line",
        "pix-fill": "pix fill",
        "pix-line": "pix line",
        "pixelfed-fill": "pixelfed fill",
        "pixelfed-line": "pixelfed line",
        "playstation-fill": "playstation fill",
        "playstation-line": "playstation line",
        "product-hunt-fill": "product hunt fill",
        "product-hunt-line": "product hunt line",
        "qq-fill": "qq fill",
        "qq-line": "qq line",
        "reactjs-fill": "reactjs fill",
        "reactjs-line": "reactjs line",
        "reddit-fill": "reddit fill",
        "reddit-line": "reddit line",
        "remix-run-fill": "remix run fill",
        "remix-run-line": "remix run line",
        "remixicon-fill": "remixicon fill",
        "remixicon-line": "remixicon line",
        "safari-fill": "safari fill",
        "safari-line": "safari line",
        "skype-fill": "skype fill",
        "skype-line": "skype line",
        "slack-fill": "slack fill",
        "slack-line": "slack line",
        "snapchat-fill": "snapchat fill",
        "snapchat-line": "snapchat line",
        "soundcloud-fill": "soundcloud fill",
        "soundcloud-line": "soundcloud line",
        "spectrum-fill": "spectrum fill",
        "spectrum-line": "spectrum line",
        "spotify-fill": "spotify fill",
        "spotify-line": "spotify line",
        "stack-overflow-fill": "stack overflow fill",
        "stack-overflow-line": "stack overflow line",
        "stackshare-fill": "stackshare fill",
        "stackshare-line": "stackshare line",
        "steam-fill": "steam fill",
        "steam-line": "steam line",
        "supabase-fill": "supabase fill",
        "supabase-line": "supabase line",
        "svelte-fill": "svelte fill",
        "svelte-line": "svelte line",
        "switch-fill": "switch fill",
        "switch-line": "switch line",
        "tailwind-css-fill": "tailwind css fill",
        "tailwind-css-line": "tailwind css line",
        "taobao-fill": "taobao fill",
        "taobao-line": "taobao line",
        "telegram-2-fill": "telegram 2 fill",
        "telegram-2-line": "telegram 2 line",
        "telegram-fill": "telegram fill",
        "telegram-line": "telegram line",
        "threads-fill": "threads fill",
        "threads-line": "threads line",
        "tiktok-fill": "tiktok fill",
        "tiktok-line": "tiktok line",
        "trello-fill": "trello fill",
        "trello-line": "trello line",
        "tumblr-fill": "tumblr fill",
        "tumblr-line": "tumblr line",
        "twitch-fill": "twitch fill",
        "twitch-line": "twitch line",
        "twitter-fill": "twitter fill",
        "twitter-line": "twitter line",
        "twitter-x-fill": "twitter x fill",
        "twitter-x-line": "twitter x line",
        "ubuntu-fill": "ubuntu fill",
        "ubuntu-line": "ubuntu line",
        "unsplash-fill": "unsplash fill",
        "unsplash-line": "unsplash line",
        "vercel-fill": "vercel fill",
        "vercel-line": "vercel line",
        "vimeo-fill": "vimeo fill",
        "vimeo-line": "vimeo line",
        "visa-fill": "visa fill",
        "visa-line": "visa line",
        "vk-fill": "vk fill",
        "vk-line": "vk line",
        "vuejs-fill": "vuejs fill",
        "vuejs-line": "vuejs line",
        "webhook-fill": "webhook fill",
        "webhook-line": "webhook line",
        "wechat-2-fill": "wechat 2 fill",
        "wechat-2-line": "wechat 2 line",
        "wechat-channels-fill": "wechat channels fill",
        "wechat-channels-line": "wechat channels line",
        "wechat-fill": "wechat fill",
        "wechat-line": "wechat line",
        "wechat-pay-fill": "wechat pay fill",
        "wechat-pay-line": "wechat pay line",
        "weibo-fill": "weibo fill",
        "weibo-line": "weibo line",
        "whatsapp-fill": "whatsapp fill",
        "whatsapp-line": "whatsapp line",
        "windows-fill": "windows fill",
        "windows-line": "windows line",
        "wordpress-fill": "wordpress fill",
        "wordpress-line": "wordpress line",
        "xbox-fill": "xbox fill",
        "xbox-line": "xbox line",
        "xing-fill": "xing fill",
        "xing-line": "xing line",
        "youtube-fill": "youtube fill",
        "youtube-line": "youtube line",
        "yuque-fill": "yuque fill",
        "yuque-line": "yuque line",
        "zcool-fill": "zcool fill",
        "zcool-line": "zcool line",
        "zhihu-fill": "zhihu fill",
        "zhihu-line": "zhihu line",
    },
    "Map": {
        "anchor-fill": "anchor fill",
        "anchor-line": "anchor line",
        "barricade-fill": "barricade fill",
        "barricade-line": "barricade line",
        "bike-fill": "bike fill",
        "bike-line": "bike line",
        "bus-2-fill": "bus 2 fill",
        "bus-2-line": "bus 2 line",
        "bus-fill": "bus fill",
        "bus-line": "bus line",
        "bus-wifi-fill": "bus wifi fill",
        "bus-wifi-line": "bus wifi line",
        "car-fill": "car fill",
        "car-line": "car line",
        "car-washing-fill": "car washing fill",
        "car-washing-line": "car washing line",
        "caravan-fill": "caravan fill",
        "caravan-line": "caravan line",
        "charging-pile-2-fill": "charging pile 2 fill",
        "charging-pile-2-line": "charging pile 2 line",
        "charging-pile-fill": "charging pile fill",
        "charging-pile-line": "charging pile line",
        "china-railway-fill": "china railway fill",
        "china-railway-line": "china railway line",
        "compass-2-fill": "compass 2 fill",
        "compass-2-line": "compass 2 line",
        "compass-3-fill": "compass 3 fill",
        "compass-3-line": "compass 3 line",
        "compass-4-fill": "compass 4 fill",
        "compass-4-line": "compass 4 line",
        "compass-discover-fill": "compass discover fill",
        "compass-discover-line": "compass discover line",
        "compass-fill": "compass fill",
        "compass-line": "compass line",
        "direction-fill": "direction fill",
        "direction-line": "direction line",
        "e-bike-2-fill": "e bike 2 fill",
        "e-bike-2-line": "e bike 2 line",
        "e-bike-fill": "e bike fill",
        "e-bike-line": "e bike line",
        "earth-fill": "earth fill",
        "earth-line": "earth line",
        "flight-land-fill": "flight land fill",
        "flight-land-line": "flight land line",
        "flight-takeoff-fill": "flight takeoff fill",
        "flight-takeoff-line": "flight takeoff line",
        "footprint-fill": "footprint fill",
        "footprint-line": "footprint line",
        "gas-station-fill": "gas station fill",
        "gas-station-line": "gas station line",
        "globe-fill": "globe fill",
        "globe-line": "globe line",
        "guide-fill": "guide fill",
        "guide-line": "guide line",
        "hotel-bed-fill": "hotel bed fill",
        "hotel-bed-line": "hotel bed line",
        "lifebuoy-fill": "lifebuoy fill",
        "lifebuoy-line": "lifebuoy line",
        "luggage-cart-fill": "luggage cart fill",
        "luggage-cart-line": "luggage cart line",
        "luggage-deposit-fill": "luggage deposit fill",
        "luggage-deposit-line": "luggage deposit line",
        "map-2-fill": "map 2 fill",
        "map-2-line": "map 2 line",
        "map-fill": "map fill",
        "map-line": "map line",
        "map-pin-2-fill": "map pin 2 fill",
        "map-pin-2-line": "map pin 2 line",
        "map-pin-3-fill": "map pin 3 fill",
        "map-pin-3-line": "map pin 3 line",
        "map-pin-4-fill": "map pin 4 fill",
        "map-pin-4-line": "map pin 4 line",
        "map-pin-5-fill": "map pin 5 fill",
        "map-pin-5-line": "map pin 5 line",
        "map-pin-add-fill": "map pin add fill",
        "map-pin-add-line": "map pin add line",
        "map-pin-fill": "map pin fill",
        "map-pin-line": "map pin line",
        "map-pin-range-fill": "map pin range fill",
        "map-pin-range-line": "map pin range line",
        "map-pin-time-fill": "map pin time fill",
        "map-pin-time-line": "map pin time line",
        "map-pin-user-fill": "map pin user fill",
        "map-pin-user-line": "map pin user line",
        "motorbike-fill": "motorbike fill",
        "motorbike-line": "motorbike line",
        "navigation-fill": "navigation fill",
        "navigation-line": "navigation line",
        "oil-fill": "oil fill",
        "oil-line": "oil line",
        "parking-box-fill": "parking box fill",
        "parking-box-line": "parking box line",
        "parking-fill": "parking fill",
        "parking-line": "parking line",
        "passport-fill": "passport fill",
        "passport-line": "passport line",
        "pin-distance-fill": "pin distance fill",
        "pin-distance-line": "pin distance line",
        "plane-fill": "plane fill",
        "plane-line": "plane line",
        "planet-fill": "planet fill",
        "planet-line": "planet line",
        "police-car-fill": "police car fill",
        "police-car-line": "police car line",
        "pushpin-2-fill": "pushpin 2 fill",
        "pushpin-2-line": "pushpin 2 line",
        "pushpin-fill": "pushpin fill",
        "pushpin-line": "pushpin line",
        "riding-fill": "riding fill",
        "riding-line": "riding line",
        "road-map-fill": "road map fill",
        "road-map-line": "road map line",
        "roadster-fill": "roadster fill",
        "roadster-line": "roadster line",
        "rocket-2-fill": "rocket 2 fill",
        "rocket-2-line": "rocket 2 line",
        "rocket-fill": "rocket fill",
        "rocket-line": "rocket line",
        "route-fill": "route fill",
        "route-line": "route line",
        "run-fill": "run fill",
        "run-line": "run line",
        "sailboat-fill": "sailboat fill",
        "sailboat-line": "sailboat line",
        "ship-2-fill": "ship 2 fill",
        "ship-2-line": "ship 2 line",
        "ship-fill": "ship fill",
        "ship-line": "ship line",
        "signal-tower-fill": "signal tower fill",
        "signal-tower-line": "signal tower line",
        "signpost-fill": "signpost fill",
        "signpost-line": "signpost line",
        "space-ship-fill": "space ship fill",
        "space-ship-line": "space ship line",
        "steering-2-fill": "steering 2 fill",
        "steering-2-line": "steering 2 line",
        "steering-fill": "steering fill",
        "steering-line": "steering line",
        "subway-fill": "subway fill",
        "subway-line": "subway line",
        "subway-wifi-fill": "subway wifi fill",
        "subway-wifi-line": "subway wifi line",
        "suitcase-2-fill": "suitcase 2 fill",
        "suitcase-2-line": "suitcase 2 line",
        "suitcase-3-fill": "suitcase 3 fill",
        "suitcase-3-line": "suitcase 3 line",
        "suitcase-fill": "suitcase fill",
        "suitcase-line": "suitcase line",
        "takeaway-fill": "takeaway fill",
        "takeaway-line": "takeaway line",
        "taxi-fill": "taxi fill",
        "taxi-line": "taxi line",
        "taxi-wifi-fill": "taxi wifi fill",
        "taxi-wifi-line": "taxi wifi line",
        "time-zone-fill": "time zone fill",
        "time-zone-line": "time zone line",
        "traffic-light-fill": "traffic light fill",
        "traffic-light-line": "traffic light line",
        "train-fill": "train fill",
        "train-line": "train line",
        "train-wifi-fill": "train wifi fill",
        "train-wifi-line": "train wifi line",
        "treasure-map-fill": "treasure map fill",
        "treasure-map-line": "treasure map line",
        "truck-fill": "truck fill",
        "truck-line": "truck line",
        "unpin-fill": "unpin fill",
        "unpin-line": "unpin line",
        "walk-fill": "walk fill",
        "walk-line": "walk line",
    },
    "Media": {
        "4k-fill": "4k fill",
        "4k-line": "4k line",
        "album-fill": "album fill",
        "album-line": "album line",
        "aspect-ratio-fill": "aspect ratio fill",
        "aspect-ratio-line": "aspect ratio line",
        "broadcast-fill": "broadcast fill",
        "broadcast-line": "broadcast line",
        "camera-2-fill": "camera 2 fill",
        "camera-2-line": "camera 2 line",
        "camera-3-fill": "camera 3 fill",
        "camera-3-line": "camera 3 line",
        "camera-4-fill": "camera 4 fill",
        "camera-4-line": "camera 4 line",
        "camera-ai-2-fill": "camera ai 2 fill",
        "camera-ai-2-line": "camera ai 2 line",
        "camera-ai-fill": "camera ai fill",
        "camera-ai-line": "camera ai line",
        "camera-fill": "camera fill",
        "camera-lens-ai-fill": "camera lens ai fill",
        "camera-lens-ai-line": "camera lens ai line",
        "camera-lens-fill": "camera lens fill",
        "camera-lens-line": "camera lens line",
        "camera-line": "camera line",
        "camera-off-fill": "camera off fill",
        "camera-off-line": "camera off line",
        "camera-switch-fill": "camera switch fill",
        "camera-switch-line": "camera switch line",
        "clapperboard-ai-fill": "clapperboard ai fill",
        "clapperboard-ai-line": "clapperboard ai line",
        "clapperboard-fill": "clapperboard fill",
        "clapperboard-line": "clapperboard line",
        "closed-captioning-ai-fill": "closed captioning ai fill",
        "closed-captioning-ai-line": "closed captioning ai line",
        "closed-captioning-fill": "closed captioning fill",
        "closed-captioning-line": "closed captioning line",
        "disc-fill": "disc fill",
        "disc-line": "disc line",
        "dv-fill": "dv fill",
        "dv-line": "dv line",
        "dvd-ai-fill": "dvd ai fill",
        "dvd-ai-line": "dvd ai line",
        "dvd-fill": "dvd fill",
        "dvd-line": "dvd line",
        "eject-fill": "eject fill",
        "eject-line": "eject line",
        "equalizer-2-fill": "equalizer 2 fill",
        "equalizer-2-line": "equalizer 2 line",
        "equalizer-3-fill": "equalizer 3 fill",
        "equalizer-3-line": "equalizer 3 line",
        "equalizer-fill": "equalizer fill",
        "equalizer-line": "equalizer line",
        "film-ai-fill": "film ai fill",
        "film-ai-line": "film ai line",
        "film-fill": "film fill",
        "film-line": "film line",
        "forward-10-fill": "forward 10 fill",
        "forward-10-line": "forward 10 line",
        "forward-15-fill": "forward 15 fill",
        "forward-15-line": "forward 15 line",
        "forward-30-fill": "forward 30 fill",
        "forward-30-line": "forward 30 line",
        "forward-5-fill": "forward 5 fill",
        "forward-5-line": "forward 5 line",
        "forward-end-fill": "forward end fill",
        "forward-end-line": "forward end line",
        "forward-end-mini-fill": "forward end mini fill",
        "forward-end-mini-line": "forward end mini line",
        "fullscreen-exit-fill": "fullscreen exit fill",
        "fullscreen-exit-line": "fullscreen exit line",
        "fullscreen-fill": "fullscreen fill",
        "fullscreen-line": "fullscreen line",
        "gallery-fill": "gallery fill",
        "gallery-line": "gallery line",
        "gallery-upload-fill": "gallery upload fill",
        "gallery-upload-line": "gallery upload line",
        "hd-fill": "hd fill",
        "hd-line": "hd line",
        "headphone-fill": "headphone fill",
        "headphone-line": "headphone line",
        "hq-fill": "hq fill",
        "hq-line": "hq line",
        "image-2-fill": "image 2 fill",
        "image-2-line": "image 2 line",
        "image-add-fill": "image add fill",
        "image-add-line": "image add line",
        "image-ai-fill": "image ai fill",
        "image-ai-line": "image ai line",
        "image-circle-ai-fill": "image circle ai fill",
        "image-circle-ai-line": "image circle ai line",
        "image-circle-fill": "image circle fill",
        "image-circle-line": "image circle line",
        "image-edit-fill": "image edit fill",
        "image-edit-line": "image edit line",
        "image-fill": "image fill",
        "image-line": "image line",
        "landscape-ai-fill": "landscape ai fill",
        "landscape-ai-line": "landscape ai line",
        "landscape-fill": "landscape fill",
        "landscape-line": "landscape line",
        "live-fill": "live fill",
        "live-line": "live line",
        "memories-fill": "memories fill",
        "memories-line": "memories line",
        "mic-2-ai-fill": "mic 2 ai fill",
        "mic-2-ai-line": "mic 2 ai line",
        "mic-2-fill": "mic 2 fill",
        "mic-2-line": "mic 2 line",
        "mic-ai-fill": "mic ai fill",
        "mic-ai-line": "mic ai line",
        "mic-fill": "mic fill",
        "mic-line": "mic line",
        "mic-off-fill": "mic off fill",
        "mic-off-line": "mic off line",
        "movie-2-ai-fill": "movie 2 ai fill",
        "movie-2-ai-line": "movie 2 ai line",
        "movie-2-fill": "movie 2 fill",
        "movie-2-line": "movie 2 line",
        "movie-ai-fill": "movie ai fill",
        "movie-ai-line": "movie ai line",
        "movie-fill": "movie fill",
        "movie-line": "movie line",
        "multi-image-fill": "multi image fill",
        "multi-image-line": "multi image line",
        "music-2-fill": "music 2 fill",
        "music-2-line": "music 2 line",
        "music-ai-fill": "music ai fill",
        "music-ai-line": "music ai line",
        "music-fill": "music fill",
        "music-line": "music line",
        "mv-ai-fill": "mv ai fill",
        "mv-ai-line": "mv ai line",
        "mv-fill": "mv fill",
        "mv-line": "mv line",
        "notification-2-fill": "notification 2 fill",
        "notification-2-line": "notification 2 line",
        "notification-3-fill": "notification 3 fill",
        "notification-3-line": "notification 3 line",
        "notification-4-fill": "notification 4 fill",
        "notification-4-line": "notification 4 line",
        "notification-fill": "notification fill",
        "notification-line": "notification line",
        "notification-off-fill": "notification off fill",
        "notification-off-line": "notification off line",
        "notification-snooze-fill": "notification snooze fill",
        "notification-snooze-line": "notification snooze line",
        "order-play-fill": "order play fill",
        "order-play-line": "order play line",
        "pause-circle-fill": "pause circle fill",
        "pause-circle-line": "pause circle line",
        "pause-fill": "pause fill",
        "pause-large-fill": "pause large fill",
        "pause-large-line": "pause large line",
        "pause-line": "pause line",
        "pause-mini-fill": "pause mini fill",
        "pause-mini-line": "pause mini line",
        "phone-camera-fill": "phone camera fill",
        "phone-camera-line": "phone camera line",
        "picture-in-picture-2-fill": "picture in picture 2 fill",
        "picture-in-picture-2-line": "picture in picture 2 line",
        "picture-in-picture-exit-fill": "picture in picture exit fill",
        "picture-in-picture-exit-line": "picture in picture exit line",
        "picture-in-picture-fill": "picture in picture fill",
        "picture-in-picture-line": "picture in picture line",
        "play-circle-fill": "play circle fill",
        "play-circle-line": "play circle line",
        "play-fill": "play fill",
        "play-large-fill": "play large fill",
        "play-large-line": "play large line",
        "play-line": "play line",
        "play-list-2-fill": "play list 2 fill",
        "play-list-2-line": "play list 2 line",
        "play-list-add-fill": "play list add fill",
        "play-list-add-line": "play list add line",
        "play-list-fill": "play list fill",
        "play-list-line": "play list line",
        "play-mini-fill": "play mini fill",
        "play-mini-line": "play mini line",
        "play-reverse-fill": "play reverse fill",
        "play-reverse-large-fill": "play reverse large fill",
        "play-reverse-large-line": "play reverse large line",
        "play-reverse-line": "play reverse line",
        "play-reverse-mini-fill": "play reverse mini fill",
        "play-reverse-mini-line": "play reverse mini line",
        "polaroid-2-fill": "polaroid 2 fill",
        "polaroid-2-line": "polaroid 2 line",
        "polaroid-fill": "polaroid fill",
        "polaroid-line": "polaroid line",
        "radio-2-fill": "radio 2 fill",
        "radio-2-line": "radio 2 line",
        "radio-fill": "radio fill",
        "radio-line": "radio line",
        "record-circle-fill": "record circle fill",
        "record-circle-line": "record circle line",
        "repeat-2-fill": "repeat 2 fill",
        "repeat-2-line": "repeat 2 line",
        "repeat-fill": "repeat fill",
        "repeat-line": "repeat line",
        "repeat-one-fill": "repeat one fill",
        "repeat-one-line": "repeat one line",
        "replay-10-fill": "replay 10 fill",
        "replay-10-line": "replay 10 line",
        "replay-15-fill": "replay 15 fill",
        "replay-15-line": "replay 15 line",
        "replay-30-fill": "replay 30 fill",
        "replay-30-line": "replay 30 line",
        "replay-5-fill": "replay 5 fill",
        "replay-5-line": "replay 5 line",
        "rewind-fill": "rewind fill",
        "rewind-line": "rewind line",
        "rewind-mini-fill": "rewind mini fill",
        "rewind-mini-line": "rewind mini line",
        "rewind-start-fill": "rewind start fill",
        "rewind-start-line": "rewind start line",
        "rewind-start-mini-fill": "rewind start mini fill",
        "rewind-start-mini-line": "rewind start mini line",
        "rhythm-fill": "rhythm fill",
        "rhythm-line": "rhythm line",
        "shuffle-fill": "shuffle fill",
        "shuffle-line": "shuffle line",
        "skip-back-fill": "skip back fill",
        "skip-back-line": "skip back line",
        "skip-back-mini-fill": "skip back mini fill",
        "skip-back-mini-line": "skip back mini line",
        "skip-forward-fill": "skip forward fill",
        "skip-forward-line": "skip forward line",
        "skip-forward-mini-fill": "skip forward mini fill",
        "skip-forward-mini-line": "skip forward mini line",
        "slow-down-fill": "slow down fill",
        "slow-down-line": "slow down line",
        "sound-module-fill": "sound module fill",
        "sound-module-line": "sound module line",
        "speaker-2-fill": "speaker 2 fill",
        "speaker-2-line": "speaker 2 line",
        "speaker-3-fill": "speaker 3 fill",
        "speaker-3-line": "speaker 3 line",
        "speaker-fill": "speaker fill",
        "speaker-line": "speaker line",
        "speed-fill": "speed fill",
        "speed-line": "speed line",
        "speed-mini-fill": "speed mini fill",
        "speed-mini-line": "speed mini line",
        "speed-up-fill": "speed up fill",
        "speed-up-line": "speed up line",
        "stop-circle-fill": "stop circle fill",
        "stop-circle-line": "stop circle line",
        "stop-fill": "stop fill",
        "stop-large-fill": "stop large fill",
        "stop-large-line": "stop large line",
        "stop-line": "stop line",
        "stop-mini-fill": "stop mini fill",
        "stop-mini-line": "stop mini line",
        "surround-sound-fill": "surround sound fill",
        "surround-sound-line": "surround sound line",
        "tape-fill": "tape fill",
        "tape-line": "tape line",
        "video-add-fill": "video add fill",
        "video-add-line": "video add line",
        "video-ai-fill": "video ai fill",
        "video-ai-line": "video ai line",
        "video-download-fill": "video download fill",
        "video-download-line": "video download line",
        "video-fill": "video fill",
        "video-line": "video line",
        "video-off-fill": "video off fill",
        "video-off-line": "video off line",
        "video-on-ai-fill": "video on ai fill",
        "video-on-ai-line": "video on ai line",
        "video-on-fill": "video on fill",
        "video-on-line": "video on line",
        "video-upload-fill": "video upload fill",
        "video-upload-line": "video upload line",
        "vidicon-2-fill": "vidicon 2 fill",
        "vidicon-2-line": "vidicon 2 line",
        "vidicon-fill": "vidicon fill",
        "vidicon-line": "vidicon line",
        "voice-ai-fill": "voice ai fill",
        "voice-ai-line": "voice ai line",
        "voiceprint-fill": "voiceprint fill",
        "voiceprint-line": "voiceprint line",
        "volume-down-fill": "volume down fill",
        "volume-down-line": "volume down line",
        "volume-mute-fill": "volume mute fill",
        "volume-mute-line": "volume mute line",
        "volume-off-vibrate-fill": "volume off vibrate fill",
        "volume-off-vibrate-line": "volume off vibrate line",
        "volume-up-fill": "volume up fill",
        "volume-up-line": "volume up line",
        "volume-vibrate-fill": "volume vibrate fill",
        "volume-vibrate-line": "volume vibrate line",
        "webcam-fill": "webcam fill",
        "webcam-line": "webcam line",
    },
    "Others": {
        "accessibility-fill": "accessibility fill",
        "accessibility-line": "accessibility line",
        "ai-generate-3d-fill": "ai generate 3d fill",
        "ai-generate-3d-line": "ai generate 3d line",
        "armchair-fill": "armchair fill",
        "armchair-line": "armchair line",
        "basketball-fill": "basketball fill",
        "basketball-line": "basketball line",
        "bell-fill": "bell fill",
        "bell-line": "bell line",
        "billiards-fill": "billiards fill",
        "billiards-line": "billiards line",
        "book-shelf-fill": "book shelf fill",
        "book-shelf-line": "book shelf line",
        "box-1-fill": "box 1 fill",
        "box-1-line": "box 1 line",
        "box-2-fill": "box 2 fill",
        "box-2-line": "box 2 line",
        "box-3-fill": "box 3 fill",
        "box-3-line": "box 3 line",
        "boxing-fill": "boxing fill",
        "boxing-line": "boxing line",
        "cactus-fill": "cactus fill",
        "cactus-line": "cactus line",
        "candle-fill": "candle fill",
        "candle-line": "candle line",
        "character-recognition-fill": "character recognition fill",
        "character-recognition-line": "character recognition line",
        "chess-fill": "chess fill",
        "chess-line": "chess line",
        "cross-fill": "cross fill",
        "cross-line": "cross line",
        "dice-1-fill": "dice 1 fill",
        "dice-1-line": "dice 1 line",
        "dice-2-fill": "dice 2 fill",
        "dice-2-line": "dice 2 line",
        "dice-3-fill": "dice 3 fill",
        "dice-3-line": "dice 3 line",
        "dice-4-fill": "dice 4 fill",
        "dice-4-line": "dice 4 line",
        "dice-5-fill": "dice 5 fill",
        "dice-5-line": "dice 5 line",
        "dice-6-fill": "dice 6 fill",
        "dice-6-line": "dice 6 line",
        "dice-fill": "dice fill",
        "dice-line": "dice line",
        "door-closed-fill": "door closed fill",
        "door-closed-line": "door closed line",
        "door-fill": "door fill",
        "door-line": "door line",
        "door-lock-box-fill": "door lock box fill",
        "door-lock-box-line": "door lock box line",
        "door-lock-fill": "door lock fill",
        "door-lock-line": "door lock line",
        "door-open-fill": "door open fill",
        "door-open-line": "door open line",
        "flower-fill": "flower fill",
        "flower-line": "flower line",
        "football-fill": "football fill",
        "football-line": "football line",
        "fridge-fill": "fridge fill",
        "fridge-line": "fridge line",
        "game-2-fill": "game 2 fill",
        "game-2-line": "game 2 line",
        "game-fill": "game fill",
        "game-line": "game line",
        "glasses-2-fill": "glasses 2 fill",
        "glasses-2-line": "glasses 2 line",
        "glasses-fill": "glasses fill",
        "glasses-line": "glasses line",
        "goggles-fill": "goggles fill",
        "goggles-line": "goggles line",
        "golf-ball-fill": "golf ball fill",
        "golf-ball-line": "golf ball line",
        "graduation-cap-fill": "graduation cap fill",
        "graduation-cap-line": "graduation cap line",
        "handbag-fill": "handbag fill",
        "handbag-line": "handbag line",
        "infinity-fill": "infinity fill",
        "infinity-line": "infinity line",
        "key-2-fill": "key 2 fill",
        "key-2-line": "key 2 line",
        "key-fill": "key fill",
        "key-line": "key line",
        "leaf-fill": "leaf fill",
        "leaf-line": "leaf line",
        "lightbulb-ai-fill": "lightbulb ai fill",
        "lightbulb-ai-line": "lightbulb ai line",
        "lightbulb-fill": "lightbulb fill",
        "lightbulb-flash-fill": "lightbulb flash fill",
        "lightbulb-flash-line": "lightbulb flash line",
        "lightbulb-line": "lightbulb line",
        "outlet-2-fill": "outlet 2 fill",
        "outlet-2-line": "outlet 2 line",
        "outlet-fill": "outlet fill",
        "outlet-line": "outlet line",
        "ping-pong-fill": "ping pong fill",
        "ping-pong-line": "ping pong line",
        "plant-fill": "plant fill",
        "plant-line": "plant line",
        "plug-2-fill": "plug 2 fill",
        "plug-2-line": "plug 2 line",
        "plug-fill": "plug fill",
        "plug-line": "plug line",
        "poker-clubs-fill": "poker clubs fill",
        "poker-clubs-line": "poker clubs line",
        "poker-diamonds-fill": "poker diamonds fill",
        "poker-diamonds-line": "poker diamonds line",
        "poker-hearts-fill": "poker hearts fill",
        "poker-hearts-line": "poker hearts line",
        "poker-spades-fill": "poker spades fill",
        "poker-spades-line": "poker spades line",
        "police-badge-fill": "police badge fill",
        "police-badge-line": "police badge line",
        "recycle-fill": "recycle fill",
        "recycle-line": "recycle line",
        "reserved-fill": "reserved fill",
        "reserved-line": "reserved line",
        "scales-2-fill": "scales 2 fill",
        "scales-2-line": "scales 2 line",
        "scales-3-fill": "scales 3 fill",
        "scales-3-line": "scales 3 line",
        "scales-fill": "scales fill",
        "scales-line": "scales line",
        "seedling-fill": "seedling fill",
        "seedling-line": "seedling line",
        "service-bell-fill": "service bell fill",
        "service-bell-line": "service bell line",
        "shirt-fill": "shirt fill",
        "shirt-line": "shirt line",
        "sofa-fill": "sofa fill",
        "sofa-line": "sofa line",
        "stairs-fill": "stairs fill",
        "stairs-line": "stairs line",
        "sword-fill": "sword fill",
        "sword-line": "sword line",
        "t-shirt-2-fill": "t shirt 2 fill",
        "t-shirt-2-line": "t shirt 2 line",
        "t-shirt-air-fill": "t shirt air fill",
        "t-shirt-air-line": "t shirt air line",
        "t-shirt-fill": "t shirt fill",
        "t-shirt-line": "t shirt line",
        "target-fill": "target fill",
        "target-line": "target line",
        "tooth-fill": "tooth fill",
        "tooth-line": "tooth line",
        "tree-fill": "tree fill",
        "tree-line": "tree line",
        "umbrella-fill": "umbrella fill",
        "umbrella-line": "umbrella line",
        "voice-recognition-fill": "voice recognition fill",
        "voice-recognition-line": "voice recognition line",
        "weight-fill": "weight fill",
        "weight-line": "weight line",
        "wheelchair-fill": "wheelchair fill",
        "wheelchair-line": "wheelchair line",
    },
    "System": {
        "add-box-fill": "add box fill",
        "add-box-line": "add box line",
        "add-circle-fill": "add circle fill",
        "add-circle-line": "add circle line",
        "add-fill": "add fill",
        "add-large-fill": "add large fill",
        "add-large-line": "add large line",
        "add-line": "add line",
        "alarm-add-fill": "alarm add fill",
        "alarm-add-line": "alarm add line",
        "alarm-fill": "alarm fill",
        "alarm-line": "alarm line",
        "alarm-snooze-fill": "alarm snooze fill",
        "alarm-snooze-line": "alarm snooze line",
        "alarm-warning-fill": "alarm warning fill",
        "alarm-warning-line": "alarm warning line",
        "alert-fill": "alert fill",
        "alert-line": "alert line",
        "apps-2-add-fill": "apps 2 add fill",
        "apps-2-add-line": "apps 2 add line",
        "apps-2-ai-fill": "apps 2 ai fill",
        "apps-2-ai-line": "apps 2 ai line",
        "apps-2-fill": "apps 2 fill",
        "apps-2-line": "apps 2 line",
        "apps-ai-fill": "apps ai fill",
        "apps-ai-line": "apps ai line",
        "apps-fill": "apps fill",
        "apps-line": "apps line",
        "check-double-fill": "check double fill",
        "check-double-line": "check double line",
        "check-fill": "check fill",
        "check-line": "check line",
        "checkbox-blank-circle-fill": "checkbox blank circle fill",
        "checkbox-blank-circle-line": "checkbox blank circle line",
        "checkbox-blank-fill": "checkbox blank fill",
        "checkbox-blank-line": "checkbox blank line",
        "checkbox-circle-fill": "checkbox circle fill",
        "checkbox-circle-line": "checkbox circle line",
        "checkbox-fill": "checkbox fill",
        "checkbox-indeterminate-fill": "checkbox indeterminate fill",
        "checkbox-indeterminate-line": "checkbox indeterminate line",
        "checkbox-line": "checkbox line",
        "checkbox-multiple-blank-fill": "checkbox multiple blank fill",
        "checkbox-multiple-blank-line": "checkbox multiple blank line",
        "checkbox-multiple-fill": "checkbox multiple fill",
        "checkbox-multiple-line": "checkbox multiple line",
        "close-circle-fill": "close circle fill",
        "close-circle-line": "close circle line",
        "close-fill": "close fill",
        "close-large-fill": "close large fill",
        "close-large-line": "close large line",
        "close-line": "close line",
        "dashboard-fill": "dashboard fill",
        "dashboard-horizontal-fill": "dashboard horizontal fill",
        "dashboard-horizontal-line": "dashboard horizontal line",
        "dashboard-line": "dashboard line",
        "delete-back-2-fill": "delete back 2 fill",
        "delete-back-2-line": "delete back 2 line",
        "delete-back-fill": "delete back fill",
        "delete-back-line": "delete back line",
        "delete-bin-2-fill": "delete bin 2 fill",
        "delete-bin-2-line": "delete bin 2 line",
        "delete-bin-3-fill": "delete bin 3 fill",
        "delete-bin-3-line": "delete bin 3 line",
        "delete-bin-4-fill": "delete bin 4 fill",
        "delete-bin-4-line": "delete bin 4 line",
        "delete-bin-5-fill": "delete bin 5 fill",
        "delete-bin-5-line": "delete bin 5 line",
        "delete-bin-6-fill": "delete bin 6 fill",
        "delete-bin-6-line": "delete bin 6 line",
        "delete-bin-7-fill": "delete bin 7 fill",
        "delete-bin-7-line": "delete bin 7 line",
        "delete-bin-fill": "delete bin fill",
        "delete-bin-line": "delete bin line",
        "divide-fill": "divide fill",
        "divide-line": "divide line",
        "download-2-fill": "download 2 fill",
        "download-2-line": "download 2 line",
        "download-cloud-2-fill": "download cloud 2 fill",
        "download-cloud-2-line": "download cloud 2 line",
        "download-cloud-fill": "download cloud fill",
        "download-cloud-line": "download cloud line",
        "download-fill": "download fill",
        "download-line": "download line",
        "equal-fill": "equal fill",
        "equal-line": "equal line",
        "error-warning-fill": "error warning fill",
        "error-warning-line": "error warning line",
        "export-fill": "export fill",
        "export-line": "export line",
        "external-link-fill": "external link fill",
        "external-link-line": "external link line",
        "eye-2-fill": "eye 2 fill",
        "eye-2-line": "eye 2 line",
        "eye-close-fill": "eye close fill",
        "eye-close-line": "eye close line",
        "eye-fill": "eye fill",
        "eye-line": "eye line",
        "eye-off-fill": "eye off fill",
        "eye-off-line": "eye off line",
        "filter-2-fill": "filter 2 fill",
        "filter-2-line": "filter 2 line",
        "filter-3-fill": "filter 3 fill",
        "filter-3-line": "filter 3 line",
        "filter-fill": "filter fill",
        "filter-line": "filter line",
        "filter-off-fill": "filter off fill",
        "filter-off-line": "filter off line",
        "find-replace-fill": "find replace fill",
        "find-replace-line": "find replace line",
        "forbid-2-fill": "forbid 2 fill",
        "forbid-2-line": "forbid 2 line",
        "forbid-fill": "forbid fill",
        "forbid-line": "forbid line",
        "function-add-fill": "function add fill",
        "function-add-line": "function add line",
        "function-ai-fill": "function ai fill",
        "function-ai-line": "function ai line",
        "function-fill": "function fill",
        "function-line": "function line",
        "history-fill": "history fill",
        "history-line": "history line",
        "hourglass-2-fill": "hourglass 2 fill",
        "hourglass-2-line": "hourglass 2 line",
        "hourglass-fill": "hourglass fill",
        "hourglass-line": "hourglass line",
        "import-fill": "import fill",
        "import-line": "import line",
        "indeterminate-circle-fill": "indeterminate circle fill",
        "indeterminate-circle-line": "indeterminate circle line",
        "information-2-fill": "information 2 fill",
        "information-2-line": "information 2 line",
        "information-fill": "information fill",
        "information-line": "information line",
        "information-off-fill": "information off fill",
        "information-off-line": "information off line",
        "list-settings-fill": "list settings fill",
        "list-settings-line": "list settings line",
        "loader-2-fill": "loader 2 fill",
        "loader-2-line": "loader 2 line",
        "loader-3-fill": "loader 3 fill",
        "loader-3-line": "loader 3 line",
        "loader-4-fill": "loader 4 fill",
        "loader-4-line": "loader 4 line",
        "loader-5-fill": "loader 5 fill",
        "loader-5-line": "loader 5 line",
        "loader-fill": "loader fill",
        "loader-line": "loader line",
        "lock-2-fill": "lock 2 fill",
        "lock-2-line": "lock 2 line",
        "lock-fill": "lock fill",
        "lock-line": "lock line",
        "lock-password-fill": "lock password fill",
        "lock-password-line": "lock password line",
        "lock-star-fill": "lock star fill",
        "lock-star-line": "lock star line",
        "lock-unlock-fill": "lock unlock fill",
        "lock-unlock-line": "lock unlock line",
        "login-box-fill": "login box fill",
        "login-box-line": "login box line",
        "login-circle-fill": "login circle fill",
        "login-circle-line": "login circle line",
        "logout-box-fill": "logout box fill",
        "logout-box-line": "logout box line",
        "logout-box-r-fill": "logout box r fill",
        "logout-box-r-line": "logout box r line",
        "logout-circle-fill": "logout circle fill",
        "logout-circle-line": "logout circle line",
        "logout-circle-r-fill": "logout circle r fill",
        "logout-circle-r-line": "logout circle r line",
        "loop-left-ai-fill": "loop left ai fill",
        "loop-left-ai-line": "loop left ai line",
        "loop-left-fill": "loop left fill",
        "loop-left-line": "loop left line",
        "loop-right-ai-fill": "loop right ai fill",
        "loop-right-ai-line": "loop right ai line",
        "loop-right-fill": "loop right fill",
        "loop-right-line": "loop right line",
        "menu-2-fill": "menu 2 fill",
        "menu-2-line": "menu 2 line",
        "menu-3-fill": "menu 3 fill",
        "menu-3-line": "menu 3 line",
        "menu-4-fill": "menu 4 fill",
        "menu-4-line": "menu 4 line",
        "menu-5-fill": "menu 5 fill",
        "menu-5-line": "menu 5 line",
        "menu-add-fill": "menu add fill",
        "menu-add-line": "menu add line",
        "menu-fill": "menu fill",
        "menu-fold-2-fill": "menu fold 2 fill",
        "menu-fold-2-line": "menu fold 2 line",
        "menu-fold-3-fill": "menu fold 3 fill",
        "menu-fold-3-line": "menu fold 3 line",
        "menu-fold-4-fill": "menu fold 4 fill",
        "menu-fold-4-line": "menu fold 4 line",
        "menu-fold-fill": "menu fold fill",
        "menu-fold-line": "menu fold line",
        "menu-line": "menu line",
        "menu-search-fill": "menu search fill",
        "menu-search-line": "menu search line",
        "menu-unfold-2-fill": "menu unfold 2 fill",
        "menu-unfold-2-line": "menu unfold 2 line",
        "menu-unfold-3-fill": "menu unfold 3 fill",
        "menu-unfold-3-line": "menu unfold 3 line",
        "menu-unfold-4-fill": "menu unfold 4 fill",
        "menu-unfold-4-line": "menu unfold 4 line",
        "menu-unfold-fill": "menu unfold fill",
        "menu-unfold-line": "menu unfold line",
        "more-2-fill": "more 2 fill",
        "more-2-line": "more 2 line",
        "more-fill": "more fill",
        "more-line": "more line",
        "notification-badge-fill": "notification badge fill",
        "notification-badge-line": "notification badge line",
        "progress-1-fill": "progress 1 fill",
        "progress-1-line": "progress 1 line",
        "progress-2-fill": "progress 2 fill",
        "progress-2-line": "progress 2 line",
        "progress-3-fill": "progress 3 fill",
        "progress-3-line": "progress 3 line",
        "progress-4-fill": "progress 4 fill",
        "progress-4-line": "progress 4 line",
        "progress-5-fill": "progress 5 fill",
        "progress-5-line": "progress 5 line",
        "progress-6-fill": "progress 6 fill",
        "progress-6-line": "progress 6 line",
        "progress-7-fill": "progress 7 fill",
        "progress-7-line": "progress 7 line",
        "progress-8-fill": "progress 8 fill",
        "progress-8-line": "progress 8 line",
        "prohibited-2-fill": "prohibited 2 fill",
        "prohibited-2-line": "prohibited 2 line",
        "prohibited-fill": "prohibited fill",
        "prohibited-line": "prohibited line",
        "question-fill": "question fill",
        "question-line": "question line",
        "radio-button-fill": "radio button fill",
        "radio-button-line": "radio button line",
        "refresh-fill": "refresh fill",
        "refresh-line": "refresh line",
        "reset-left-fill": "reset left fill",
        "reset-left-line": "reset left line",
        "reset-right-fill": "reset right fill",
        "reset-right-line": "reset right line",
        "search-2-fill": "search 2 fill",
        "search-2-line": "search 2 line",
        "search-ai-2-fill": "search ai 2 fill",
        "search-ai-2-line": "search ai 2 line",
        "search-ai-3-fill": "search ai 3 fill",
        "search-ai-3-line": "search ai 3 line",
        "search-ai-4-fill": "search ai 4 fill",
        "search-ai-4-line": "search ai 4 line",
        "search-ai-fill": "search ai fill",
        "search-ai-line": "search ai line",
        "search-eye-fill": "search eye fill",
        "search-eye-line": "search eye line",
        "search-fill": "search fill",
        "search-line": "search line",
        "settings-2-fill": "settings 2 fill",
        "settings-2-line": "settings 2 line",
        "settings-3-fill": "settings 3 fill",
        "settings-3-line": "settings 3 line",
        "settings-4-fill": "settings 4 fill",
        "settings-4-line": "settings 4 line",
        "settings-5-fill": "settings 5 fill",
        "settings-5-line": "settings 5 line",
        "settings-6-fill": "settings 6 fill",
        "settings-6-line": "settings 6 line",
        "settings-fill": "settings fill",
        "settings-line": "settings line",
        "share-2-fill": "share 2 fill",
        "share-2-line": "share 2 line",
        "share-box-fill": "share box fill",
        "share-box-line": "share box line",
        "share-circle-fill": "share circle fill",
        "share-circle-line": "share circle line",
        "share-fill": "share fill",
        "share-forward-2-fill": "share forward 2 fill",
        "share-forward-2-line": "share forward 2 line",
        "share-forward-box-fill": "share forward box fill",
        "share-forward-box-line": "share forward box line",
        "share-forward-fill": "share forward fill",
        "share-forward-line": "share forward line",
        "share-line": "share line",
        "shield-check-fill": "shield check fill",
        "shield-check-line": "shield check line",
        "shield-cross-fill": "shield cross fill",
        "shield-cross-line": "shield cross line",
        "shield-fill": "shield fill",
        "shield-flash-fill": "shield flash fill",
        "shield-flash-line": "shield flash line",
        "shield-keyhole-fill": "shield keyhole fill",
        "shield-keyhole-line": "shield keyhole line",
        "shield-line": "shield line",
        "shield-star-fill": "shield star fill",
        "shield-star-line": "shield star line",
        "shield-user-fill": "shield user fill",
        "shield-user-line": "shield user line",
        "side-bar-fill": "side bar fill",
        "side-bar-line": "side bar line",
        "sidebar-fold-fill": "sidebar fold fill",
        "sidebar-fold-line": "sidebar fold line",
        "sidebar-unfold-fill": "sidebar unfold fill",
        "sidebar-unfold-line": "sidebar unfold line",
        "spam-2-fill": "spam 2 fill",
        "spam-2-line": "spam 2 line",
        "spam-3-fill": "spam 3 fill",
        "spam-3-line": "spam 3 line",
        "spam-fill": "spam fill",
        "spam-line": "spam line",
        "star-fill": "star fill",
        "star-half-fill": "star half fill",
        "star-half-line": "star half line",
        "star-half-s-fill": "star half s fill",
        "star-half-s-line": "star half s line",
        "star-line": "star line",
        "star-off-fill": "star off fill",
        "star-off-line": "star off line",
        "star-s-fill": "star s fill",
        "star-s-line": "star s line",
        "subtract-fill": "subtract fill",
        "subtract-line": "subtract line",
        "thumb-down-fill": "thumb down fill",
        "thumb-down-line": "thumb down line",
        "thumb-up-fill": "thumb up fill",
        "thumb-up-line": "thumb up line",
        "time-fill": "time fill",
        "time-line": "time line",
        "timer-2-fill": "timer 2 fill",
        "timer-2-line": "timer 2 line",
        "timer-fill": "timer fill",
        "timer-flash-fill": "timer flash fill",
        "timer-flash-line": "timer flash line",
        "timer-line": "timer line",
        "toggle-fill": "toggle fill",
        "toggle-line": "toggle line",
        "upload-2-fill": "upload 2 fill",
        "upload-2-line": "upload 2 line",
        "upload-cloud-2-fill": "upload cloud 2 fill",
        "upload-cloud-2-line": "upload cloud 2 line",
        "upload-cloud-fill": "upload cloud fill",
        "upload-cloud-line": "upload cloud line",
        "upload-fill": "upload fill",
        "upload-line": "upload line",
        "zoom-in-fill": "zoom in fill",
        "zoom-in-line": "zoom in line",
        "zoom-out-fill": "zoom out fill",
        "zoom-out-line": "zoom out line",
    },
    "User & Faces": {
        "account-box-2-fill": "account box 2 fill",
        "account-box-2-line": "account box 2 line",
        "account-box-fill": "account box fill",
        "account-box-line": "account box line",
        "account-circle-2-fill": "account circle 2 fill",
        "account-circle-2-line": "account circle 2 line",
        "account-circle-fill": "account circle fill",
        "account-circle-line": "account circle line",
        "account-pin-box-fill": "account pin box fill",
        "account-pin-box-line": "account pin box line",
        "account-pin-circle-fill": "account pin circle fill",
        "account-pin-circle-line": "account pin circle line",
        "admin-fill": "admin fill",
        "admin-line": "admin line",
        "ai-agent-fill": "ai agent fill",
        "ai-agent-line": "ai agent line",
        "aliens-fill": "aliens fill",
        "aliens-line": "aliens line",
        "bear-smile-fill": "bear smile fill",
        "bear-smile-line": "bear smile line",
        "body-scan-fill": "body scan fill",
        "body-scan-line": "body scan line",
        "contacts-fill": "contacts fill",
        "contacts-line": "contacts line",
        "criminal-fill": "criminal fill",
        "criminal-line": "criminal line",
        "emotion-2-fill": "emotion 2 fill",
        "emotion-2-line": "emotion 2 line",
        "emotion-fill": "emotion fill",
        "emotion-happy-fill": "emotion happy fill",
        "emotion-happy-line": "emotion happy line",
        "emotion-laugh-fill": "emotion laugh fill",
        "emotion-laugh-line": "emotion laugh line",
        "emotion-line": "emotion line",
        "emotion-normal-fill": "emotion normal fill",
        "emotion-normal-line": "emotion normal line",
        "emotion-sad-fill": "emotion sad fill",
        "emotion-sad-line": "emotion sad line",
        "emotion-unhappy-fill": "emotion unhappy fill",
        "emotion-unhappy-line": "emotion unhappy line",
        "genderless-fill": "genderless fill",
        "genderless-line": "genderless line",
        "ghost-2-fill": "ghost 2 fill",
        "ghost-2-line": "ghost 2 line",
        "ghost-fill": "ghost fill",
        "ghost-line": "ghost line",
        "ghost-smile-fill": "ghost smile fill",
        "ghost-smile-line": "ghost smile line",
        "group-2-fill": "group 2 fill",
        "group-2-line": "group 2 line",
        "group-3-fill": "group 3 fill",
        "group-3-line": "group 3 line",
        "group-fill": "group fill",
        "group-line": "group line",
        "men-fill": "men fill",
        "men-line": "men line",
        "mickey-fill": "mickey fill",
        "mickey-line": "mickey line",
        "open-arm-fill": "open arm fill",
        "open-arm-line": "open arm line",
        "parent-fill": "parent fill",
        "parent-line": "parent line",
        "robot-2-fill": "robot 2 fill",
        "robot-2-line": "robot 2 line",
        "robot-3-fill": "robot 3 fill",
        "robot-3-line": "robot 3 line",
        "robot-fill": "robot fill",
        "robot-line": "robot line",
        "skull-2-fill": "skull 2 fill",
        "skull-2-line": "skull 2 line",
        "skull-fill": "skull fill",
        "skull-line": "skull line",
        "spy-fill": "spy fill",
        "spy-line": "spy line",
        "star-smile-fill": "star smile fill",
        "star-smile-line": "star smile line",
        "team-fill": "team fill",
        "team-line": "team line",
        "travesti-fill": "travesti fill",
        "travesti-line": "travesti line",
        "user-2-fill": "user 2 fill",
        "user-2-line": "user 2 line",
        "user-3-fill": "user 3 fill",
        "user-3-line": "user 3 line",
        "user-4-fill": "user 4 fill",
        "user-4-line": "user 4 line",
        "user-5-fill": "user 5 fill",
        "user-5-line": "user 5 line",
        "user-6-fill": "user 6 fill",
        "user-6-line": "user 6 line",
        "user-add-fill": "user add fill",
        "user-add-line": "user add line",
        "user-community-fill": "user community fill",
        "user-community-line": "user community line",
        "user-fill": "user fill",
        "user-follow-fill": "user follow fill",
        "user-follow-line": "user follow line",
        "user-forbid-fill": "user forbid fill",
        "user-forbid-line": "user forbid line",
        "user-heart-fill": "user heart fill",
        "user-heart-line": "user heart line",
        "user-line": "user line",
        "user-location-fill": "user location fill",
        "user-location-line": "user location line",
        "user-minus-fill": "user minus fill",
        "user-minus-line": "user minus line",
        "user-received-2-fill": "user received 2 fill",
        "user-received-2-line": "user received 2 line",
        "user-received-fill": "user received fill",
        "user-received-line": "user received line",
        "user-search-fill": "user search fill",
        "user-search-line": "user search line",
        "user-settings-fill": "user settings fill",
        "user-settings-line": "user settings line",
        "user-shared-2-fill": "user shared 2 fill",
        "user-shared-2-line": "user shared 2 line",
        "user-shared-fill": "user shared fill",
        "user-shared-line": "user shared line",
        "user-smile-fill": "user smile fill",
        "user-smile-line": "user smile line",
        "user-star-fill": "user star fill",
        "user-star-line": "user star line",
        "user-unfollow-fill": "user unfollow fill",
        "user-unfollow-line": "user unfollow line",
        "user-voice-fill": "user voice fill",
        "user-voice-line": "user voice line",
        "women-fill": "women fill",
        "women-line": "women line",
    },
    "Weather": {
        "blaze-fill": "blaze fill",
        "blaze-line": "blaze line",
        "celsius-fill": "celsius fill",
        "celsius-line": "celsius line",
        "cloud-windy-fill": "cloud windy fill",
        "cloud-windy-line": "cloud windy line",
        "cloudy-2-fill": "cloudy 2 fill",
        "cloudy-2-line": "cloudy 2 line",
        "cloudy-fill": "cloudy fill",
        "cloudy-line": "cloudy line",
        "drizzle-fill": "drizzle fill",
        "drizzle-line": "drizzle line",
        "earthquake-fill": "earthquake fill",
        "earthquake-line": "earthquake line",
        "fahrenheit-fill": "fahrenheit fill",
        "fahrenheit-line": "fahrenheit line",
        "fire-fill": "fire fill",
        "fire-line": "fire line",
        "flashlight-fill": "flashlight fill",
        "flashlight-line": "flashlight line",
        "flood-fill": "flood fill",
        "flood-line": "flood line",
        "foggy-fill": "foggy fill",
        "foggy-line": "foggy line",
        "hail-fill": "hail fill",
        "hail-line": "hail line",
        "haze-2-fill": "haze 2 fill",
        "haze-2-line": "haze 2 line",
        "haze-fill": "haze fill",
        "haze-line": "haze line",
        "heavy-showers-fill": "heavy showers fill",
        "heavy-showers-line": "heavy showers line",
        "meteor-fill": "meteor fill",
        "meteor-line": "meteor line",
        "mist-fill": "mist fill",
        "mist-line": "mist line",
        "moon-clear-fill": "moon clear fill",
        "moon-clear-line": "moon clear line",
        "moon-cloudy-fill": "moon cloudy fill",
        "moon-cloudy-line": "moon cloudy line",
        "moon-fill": "moon fill",
        "moon-foggy-fill": "moon foggy fill",
        "moon-foggy-line": "moon foggy line",
        "moon-line": "moon line",
        "rainbow-fill": "rainbow fill",
        "rainbow-line": "rainbow line",
        "rainy-fill": "rainy fill",
        "rainy-line": "rainy line",
        "shining-2-fill": "shining 2 fill",
        "shining-2-line": "shining 2 line",
        "shining-fill": "shining fill",
        "shining-line": "shining line",
        "showers-fill": "showers fill",
        "showers-line": "showers line",
        "snowflake-fill": "snowflake fill",
        "snowflake-line": "snowflake line",
        "snowy-fill": "snowy fill",
        "snowy-line": "snowy line",
        "sparkling-2-fill": "sparkling 2 fill",
        "sparkling-2-line": "sparkling 2 line",
        "sparkling-fill": "sparkling fill",
        "sparkling-line": "sparkling line",
        "sun-cloudy-fill": "sun cloudy fill",
        "sun-cloudy-line": "sun cloudy line",
        "sun-fill": "sun fill",
        "sun-foggy-fill": "sun foggy fill",
        "sun-foggy-line": "sun foggy line",
        "sun-line": "sun line",
        "temp-cold-fill": "temp cold fill",
        "temp-cold-line": "temp cold line",
        "temp-hot-fill": "temp hot fill",
        "temp-hot-line": "temp hot line",
        "thunderstorms-fill": "thunderstorms fill",
        "thunderstorms-line": "thunderstorms line",
        "tornado-fill": "tornado fill",
        "tornado-line": "tornado line",
        "typhoon-fill": "typhoon fill",
        "typhoon-line": "typhoon line",
        "water-percent-fill": "water percent fill",
        "water-percent-line": "water percent line",
        "windy-fill": "windy fill",
        "windy-line": "windy line",
    },
}


def get_icon_choices():
    """
    Return icon choices for Django form field.
    """
    return [
        (icon, icon.replace("ri-", "").replace("-", " ").title())
        for icon in REMIX_ICONS
    ]


def get_icon_names():
    """
    Return list of all icon names.
    """
    return REMIX_ICONS



"""
Template tags for rendering RemixIcons in Django templates.
"""

from django import template
from django.utils.safestring import mark_safe

from django_remix_icon.remix_icons import REMIX_ICONS

register = template.Library()


def get_all_icon_names():
    """
    Get a flat list of all icon names with 'ri-' prefix.
    """
    icon_names = []
    for category, icons in REMIX_ICONS.items():
        for icon_name in icons.keys():
            icon_names.append(f"ri-{icon_name}")
    return icon_names


@register.simple_tag
def remix_icon(icon_name, **kwargs):
    """
    Render a RemixIcon with optional attributes.

    Usage:
        {% remix_icon 'ri-home-line' %}
        {% remix_icon 'ri-user-fill' class='text-blue-500' size='24' %}
        {% remix_icon instance.icon_field %}
        {% remix_icon 'ri-heart-line' style='color: red; font-size: 20px;' %}

    Args:
        icon_name: The RemixIcon name (e.g., 'ri-home-line')
        **kwargs: Additional HTML attributes (class, style, size, etc.)

    Returns:
        HTML <i> tag with the icon
    """
    if not icon_name:
        return ''

    # Validate icon name
    if icon_name not in get_all_icon_names():
        # Return empty or a placeholder for invalid icons
        return mark_safe(f'<i class="ri-question-line" title="Invalid icon: {icon_name}"></i>')

    # Build attributes
    attrs = {}

    # Handle CSS classes
    css_classes = [icon_name]
    if 'class' in kwargs:
        css_classes.append(kwargs.pop('class'))
    attrs['class'] = ' '.join(css_classes)

    # Handle size attribute (convert to font-size style)
    if 'size' in kwargs:
        size = kwargs.pop('size')
        try:
            # If size is numeric, add 'px'
            if isinstance(size, (int, float)) or size.isdigit():
                size = f"{size}px"

            style = attrs.get('style', '')
            if style and not style.endswith(';'):
                style += ';'
            style += f"font-size: {size};"
            attrs['style'] = style
        except (ValueError, AttributeError):
            pass  # Invalid size, ignore

    # Add any remaining attributes
    for key, value in kwargs.items():
        attrs[key] = value

    # Build the HTML tag
    attr_string = ''
    for key, value in attrs.items():
        attr_string += f' {key}="{value}"'

    return mark_safe(f'<i{attr_string}></i>')


@register.simple_tag
def remix_icon_css():
    """
    Include RemixIcon CSS from CDN.

    Usage:
        {% remix_icon_css %}

    Returns:
        HTML link tag for RemixIcon CSS
    """
    return mark_safe(
        '<link href="https://cdn.jsdelivr.net/npm/remixicon@4.7.0/fonts/remixicon.css" rel="stylesheet">'
    )


@register.simple_tag
def remix_icon_version():
    """
    Get the RemixIcon version being used.

    Usage:
        {% remix_icon_version %}

    Returns:
        Version string
    """
    return "4.7.0"


@register.filter
def is_remix_icon(icon_name):
    """
    Check if a string is a valid RemixIcon name.

    Usage:
        {% if icon_field|is_remix_icon %}
            {% remix_icon icon_field %}
        {% endif %}

    Args:
        icon_name: The icon name to check

    Returns:
        Boolean indicating if the icon name is valid
    """
    if not icon_name:
        return False
    return icon_name in get_all_icon_names()


@register.inclusion_tag('django_remix_icon/icon_with_text.html')
def remix_icon_with_text(icon_name, text, **kwargs):
    """
    Render an icon with accompanying text.

    Usage:
        {% remix_icon_with_text 'ri-home-line' 'Home' %}
        {% remix_icon_with_text instance.icon 'Click here' class='btn btn-primary' %}

    Args:
        icon_name: The RemixIcon name
        text: Text to display alongside the icon
        **kwargs: Additional HTML attributes for the container

    Returns:
        Rendered template with icon and text
    """
    return {
        'icon_name': icon_name,
        'text': text,
        'attrs': kwargs,
        'is_valid_icon': icon_name in get_all_icon_names() if icon_name else False,
    }


@register.simple_tag
def remix_icon_list(category=None, limit=None):
    """
    Get a list of RemixIcon names, optionally filtered by category.

    Usage:
        {% remix_icon_list as all_icons %}
        {% remix_icon_list category='Arrows' limit=10 as arrow_icons %}
        {% remix_icon_list category='user' limit=10 as user_icons %}

    Args:
        category: Filter icons by category name or search in icon names (optional)
        limit: Limit number of icons returned (optional)

    Returns:
        List of icon names (with 'ri-' prefix)
    """
    icons = []

    # If category is specified, try to match exact category name first
    if category:
        category_str = str(category)
        # Check if it matches an exact category name
        if category_str in REMIX_ICONS:
            # Return icons from that specific category
            for icon_name in REMIX_ICONS[category_str].keys():
                icons.append(f"ri-{icon_name}")
        else:
            # Otherwise, search in icon names and category names
            category_lower = category_str.lower()
            for cat_name, cat_icons in REMIX_ICONS.items():
                # Check if category name matches
                if category_lower in cat_name.lower():
                    for icon_name in cat_icons.keys():
                        icons.append(f"ri-{icon_name}")
                else:
                    # Check individual icon names
                    for icon_name in cat_icons.keys():
                        if category_lower in icon_name.lower():
                            icons.append(f"ri-{icon_name}")
    else:
        # No category filter, return all icons
        for cat_icons in REMIX_ICONS.values():
            for icon_name in cat_icons.keys():
                icons.append(f"ri-{icon_name}")

    if limit:
        try:
            limit = int(limit)
            icons = icons[:limit]
        except (ValueError, TypeError):
            pass  # Invalid limit, return all

    return icons



"""
URL configuration for django-remix-icon.
"""

from django.urls import path
from django_remix_icon import views

app_name = 'django_remix_icon'

urlpatterns = [
    path('search/', views.IconSearchView.as_view(), name='icon_search'),
    path('list/', views.icon_list_view, name='icon_list'),
]
